<?php
/**
 * @version $Id: frontControleur.php 2 2009-10-25 12:25:37Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of miniFramework.
 *
 * miniFramework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * miniFramework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with miniFramework.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

/**
 * Le frontControleur est instanci dans le fichier index.php et organise la lecture de la requte pour renvoyer
 * ce qu'il faut au client
 *
 * @author jjocal
 */
class frontControleur {

  /**
   * Module  charger par l'application, peut tre nul.
   * @var string Nom du module charg
   */
  private $_module = NULL;

  /**
   * Classe du controleur  instancier
   * @var string Nom de la classe controleur  cherger
   */
  private $_controleur = NULL;

  /**
   * Mthode appele par la requte html
   * @var string Mthode du controleur  appeler
   */
  private $_action = "index";

  /**
   * Nom de la vue qui est appele par le controleur, par dfaut gale  l'action mais peut tre modifie par le controleur.
   * @var string Vue renvoye
   */
  private $_vue = "index";

  /**
   * Information complmentaire
   * @var <type> Information particulire appele par la requte HTML
   */
  private $_info = NULL;

  /**
   * Chemin absolue (entre le domaine et l'application)
   * @var string Path global de l'application
   */
  private $_path = "/";

  /**
   * Configuration des routes prvues par l'application
   * @var array Se charge par un fichier de configuration.
   */
  private $_routes = array();

  /**
   * Ensemble des informations envoyes en GET et en POST par le client
   * @var object requeteControleur
   */
  private $_requete = array();

  /**
   * L'application demande t-elle une authentification de l'utilisateur
   *
   * @var boolean true/false
   * @var string path complet de l'application avec le / au dbut
   */
  private $_auth = false;

  public function __construct($path, $auth){

    /**
     * Tous les fichiers  inclure ainsi que le lanceur Propel sont inclus par la classe includeControleur
     */
    include 'lib/includeControleur.php';
    new includeControleur();

    $this->setRoutes();
    $this->setRequete();
    $this->_path = $path;
    $this->_auth = new authControleur($auth);

    $this->decomposeUrl();

    if ($auth === true AND ($this->_controleur != 'login')){
      if (authControleur::isAuthWithSession() === false){
        $this->redirect_to(array("controleur"=>'login', "action"=>'index', "info"=>'-'));
      }
    }

    $this->chargeControleur();

  }

  /**
   * Mthode qui analyse l'url envoye par l'utilisateur pour dterminer le module, le controleur, l'action et l'info  charger
   */
  protected function decomposeUrl(){

    $url = substr($_SERVER["REQUEST_URI"], strlen($this->_path) + 1);
    $test = explode("/", $url);
    $nbre = count($test);
    $array = array();

    if (array_key_exists($nbre, $this->_routes)){

      $a = 0; // itrateur
      foreach ($this->_routes[$nbre] as $tab) {
        $array[$tab] = $test[$a];
        $a++;
      }

    }

    // On charge alors la configuration pour cette requte
    $this->_module      = (array_key_exists("module", $array)) ? $array["module"] : NULL;
    $this->_controleur  = (array_key_exists("controleur", $array)) ? $array["controleur"] : 'login';
    $this->_action      = (array_key_exists("action", $array)) ? $array["action"] : 'index';
    $this->_vue         = (array_key_exists("action", $array)) ? $array["action"] : 'index';
    # On explose info pour enlever les GET
    $testinfo           = (array_key_exists("info", $array)) ? explode("?", $array["info"]) : array('-');
    $this->_info        = $testinfo[0];

  }

  protected function chargeControleur(){

    $module = (!is_null($this->_module)) ? '/'.$this->_module : NULL;

    include 'app'.$module.'/controleurs/'.$this->_controleur.'Controleur.php';

    $controleurName = $this->_controleur.'Controleur';

    $controleur = new $controleurName($this->_requete, $this->getParams(), $this->_auth);

    $this->choixSortie($controleur);

  }

  protected function choixSortie($controleur){

    switch ($controleur->getModeSortie()) {
      case 'html':
        $this->html($controleur);
        break;
      case 'xml':
        $this->xml($controleur);
        break;
      case 'odt':
        $this->odt($controleur);
        break;
      case 'pdf':
        $this->pdf($controleur);
        break;

    default:
      $this->html($controleur);
      break;
}

  }

  private function setRoutes(){

    include 'app/routes/base.php';
    $this->_routes = $route;

  }

  private function setRequete(){

    $this->_requete = new requeteControleur();

  }

  private function getParams(){

    return array('module' => $this->_module,
                 'controleur' => $this->_controleur,
                 'action' => $this->_action,
                 'vue' => $this->_vue,
                 'info' => $this->_info,
                 'path' => $this->_path);

  }

  /**
   * Redirige l'utilisateur avec la fonction php header()
   *
   * @param array $options module, controleur, action, info
   */
  protected function redirect_to($options = array()){
    $module     = array_key_exists('module', $options) ? '/'.$options["module"] : ((!is_null($this->_module)) ? '/'.$this->_module : NULL);
    $controleur = array_key_exists('controleur', $options) ? '/'.$options["controleur"] : ((!is_null($this->_controleur)) ? '/'.$this->_controleur : NULL);
    $action     = array_key_exists('action', $options) ? '/'.$options["action"] : ((!is_null($this->_action)) ? '/'.$this->_action : NULL);
    $info       = array_key_exists('info', $options) ? '/'.$options["info"] : ((!is_null($this->_info)) ? '/'.$this->_info : '/');

    header("Location:http://".$_SERVER["HTTP_HOST"].$this->_path.$module.$controleur.$action.$info);
    Die();
  }

  private function html($controleur){
    $controleur->getVue();
  }

  private function xml($controleur){
    Die("NO DISPO ".__METHOD__);
  }

  private function odt($controleur){
    Die("NO DISPO".__METHOD__);
  }

  private function pdf($controleur){
    Die("NO DISPO".__METHOD__);
  }
}
?>
