<?php
/**
 * @version $Id: requeteControleur.php 2 2009-10-25 12:25:37Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of miniFramework.
 *
 * miniFramework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * miniFramework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with miniFramework.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

/**
 * Le controleur requeteControleur s'occupe de trier la requte POST et GET pour dterminer de quel type de
 * requte il s'agit (GET, POST, PUT, DELETE) et du contenu de ces informations.
 *
 * @author jjocal
 */
class requeteControleur {

  private $_get     = NULL;
  private $_post    = NULL;
  private $_put     = NULL;
  private $_delete  = NULL;

  /**
   * L'application permet de grer les 4 niveau du web : get, post, put et delete
   * @var string $_SERVER["REQUEST_METHOD"]
   */
  private $_methode = NULL;

  /**
   * Le construteur analyse la requte et dispatche les informations utiles dans l'application.
   */
  public function  __construct() {

    $this->_methode = $_SERVER["REQUEST_METHOD"];
    $this->_get     = $this->setGet();
    $this->_post    = $this->setPost();
    $this->_put     = $this->setPut();
    $this->_delete  = $this->setDelete();

  }

  private function setPost(){
    if ($this->_methode == "POST" AND !array_key_exists("method", $_POST)){
      return $_POST;
    }else{
      return NULL;
    }
  }
  private function setPut(){
    if ($this->_methode == "POST" AND array_key_exists("method", $_POST) AND $_POST["method"] == "put"){
      return $_POST;
    }else{
      return NULL;
    }
  }
  private function setDelete(){
    if ($this->_methode == "POST" AND array_key_exists("method", $_POST) AND $_POST["method"] == "delete"){
      return $_POST;
    }else{
      return NULL;
    }
  }
  private function setGet(){
    return $_GET;
  }

  public function isGet(){
    if (is_array($this->_get) AND !empty ($this->_get)){
      return true;
    }else{
      return false;
    }
  }

  public function isPost(){
    if (is_array($this->_post) AND is_null($this->_put) AND is_null($this->_delete)){
      return true;
    }else{
      return false;
    }
  }

  public function isPut(){
    if (is_array($this->_put) AND is_null($this->_post) AND is_null($this->_delete)){
      return true;
    }else{
      return false;
    }
  }

  public function isDelete(){
    if (is_array($this->_delete) AND is_null($this->_put) AND is_null($this->_post)){
      return true;
    }else{
      return false;
    }
  }

  /**
   * Mthode magique qui renvoie une valeur appele comme un attribut de cette classe
   * Permet d'appeler uniquement les valeurs en POST
   *
   * @param string $name
   * @return string La valeur en question ou NULL
   */
  public function  __get($name) {
    $retour = array_key_exists($name, $_POST) ? $_POST[$name] : NULL;
    return $retour;
  }

  /**
   * Renvoie la valeur du champ GET appel (NULL si inexistant).
   *
   * @param string $name champ  tester
   * @return string (NULL si ce champ n'existe pas)
   */
  public function getGet($name){
    $retour = array_key_exists($name, $_GET) ? $_GET[$name] : NULL;
    return $retour;
  }

}
?>
