<?php

require 'competencesrb/om/BaseBilanPeer.php';


/**
 * Skeleton subclass for performing query and update operations on the 'bilans' table.
 *
 * Liste des bilans
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    competencesrb
 */
class BilanPeer extends BaseBilanPeer {

  /**
   * Renvoie la liste des bilans d'un professeur sur un lve pour une priode donne
   *
   * @param integer $professeurId
   * @param integer $eleveId
   * @param object $periode
   * @return array tableau des objets bilan
   */
  public static function listeBilansCeProfesseurCetEleveCettePeriode(utilisateur $professeur, $eleveId, periode $periode = NULL){

    if (is_null($periode)){
      $periode = PeriodePeer::getPeriodeActuelle($professeur->getRne());
    }

    $c = new Criteria();
    $c->add(BilanPeer::PROFESSEUR_ID, $professeur->getId());
    $c->add(BilanPeer::ELEVE_ID, $eleveId);
    $criter1 = $c->getNewCriterion(BilanPeer::DATE, $periode->getDebut(), Criteria::GREATER_EQUAL);
    $criter2 = $c->getNewCriterion(BilanPeer::DATE, $periode->getFin(), Criteria::LESS_EQUAL);
    $criter1->addAnd($criter2);
    $c->add($criter1);

    return BilanPeer::doSelect($c);

  }
  /**
   * Renvoie la liste des bilans d'un professeur sur un lve pour une priode donne
   *
   * @param integer $professeurId
   * @param integer $eleveId
   * @param object $periode
   * @return array tableau des objets bilan
   */
  public static function listeBilansCeProfesseurCetEleveCetteCompetenceCettePeriode(utilisateur $professeur, $eleveId, $competenceId, periode $periode = NULL){

    if (is_null($periode)){
      $periode = PeriodePeer::getPeriodeActuelle($professeur->getRne());
    }

    $c = new Criteria();
    $c->add(BilanPeer::PROFESSEUR_ID, $professeur->getId());
    $c->add(BilanPeer::ELEVE_ID, $eleveId);
    $c->add(BilanPeer::COMPETENCE_ID, $competenceId);
    $criter1 = $c->getNewCriterion(BilanPeer::DATE, $periode->getDebut(), Criteria::GREATER_EQUAL);
    $criter2 = $c->getNewCriterion(BilanPeer::DATE, $periode->getFin(), Criteria::LESS_EQUAL);
    $criter1->addAnd($criter2);
    $c->add($criter1);

    return BilanPeer::doSelect($c);

  }
} // BilanPeer
