<?php

require 'competencesrb/om/BaseGrillePeer.php';


/**
 * Skeleton subclass for performing query and update operations on the 'grilles' table.
 *
 * Liste des grilles de competences
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    competencesrb
 */
class GrillePeer extends BaseGrillePeer {

  /**
   * Teste si une grille est utilise par un utilisateur (professeur) ou pas
   *
   * @param object $user
   * @param integer $grilleId
   * @return boolean false/object grille
   */
  public static function utilisateurUtiliseCetteGrille(Utilisateur $user, $grilleId){

    $cr = new Criteria();
    $cr->add(GrillePeer::ID, $grilleId, Criteria::EQUAL);
    $cr->add(GrillePeer::UTILISATEUR_ID, array($user->getId(), '0'), Criteria::IN);
    $test = self::doSelect($cr);

    if (empty ($test)){
      return false;
    }else{
      return $test[0];
    }

  } // utilisateurUtiliseCetteGrille

  /**
   * Teste si une grille est utilise par un utilisateur (professeur) ou pas sur un groupe en particulier
   *
   * @param object $user
   * @param integer $grilleId
   * @param integer $groupeId
   * @return boolean false/object JGrilleGroupePeerJoinGrille
   */
  public static function utilisateurUtiliseCetteGrilleEtCeGroupe(Utilisateur $user, $grilleId, $groupeId){

    $cr = new Criteria();
    $cr->add(GrillePeer::ID, $grilleId, Criteria::EQUAL);
    $cr->add(GrillePeer::UTILISATEUR_ID, array($user->getId(), '0'), Criteria::IN);
    $cr->add(JGrilleGroupePeer::GROUPE_ID, $groupeId, Criteria::EQUAL);
    $test = JGrilleGroupePeer::doSelectJoinGrille($cr);

    if (empty ($test)){
      return false;
    }else{
      $test[0]->getGroupe(); // on ajoute le groupe
      $test[0]->getGroupe()->getJGroupeElevesJoinUtilisateur(); // les JGroupeEleves
      return $test[0];
    }

  }

  /**
   * Renvoie un tableau de la liste des objets grilles (par ordre de cration) de l'utilisateur appel
   * Renvoie galement les grilles peda si ncessaire
   *
   * @param object $user utilisateur
   * @param boolean $peda si true, alors on ajoute les grilles pdagogiques
   */
  public static function listeGrillesJoinGroupesCetUtilisateur(utilisateur $user, $peda = false){

    $c = new Criteria();
    if ($peda === true){
      $c->add(GrillePeer::UTILISATEUR_ID, array($user->getId(), '0'), Criteria::IN);
    }else{
      $c->add(GrillePeer::UTILISATEUR_ID, $user->getId(), Criteria::EQUAL);
    }
    $c->addAscendingOrderByColumn(GrillePeer::CREATED_ON);
    $liste = GrillePeer::doSelect($c);

    $tab = array();
    $iter = 0;
    foreach ($liste as $grille){

      $grille->getJGrilleGroupesJoinGroupe();
      $tab[] = $grille;
      # On rcupre maintenant la liste des groupes et on les ajoute  $tab
      //$tab[$iter][] = $grille->getJGrilleGroupesJoinGroupe();

      ++$iter;
    }

    return $tab;

  }

} // GrillePeer
