<?php

require 'competencesrb/om/BaseUtilisateurPeer.php';


/**
 * Skeleton subclass for performing query and update operations on the 'utilisateurs' table.
 *
 * utilisateurs
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    competencesrb
 */
class UtilisateurPeer extends BaseUtilisateurPeer {

  /**
   * tableau php des lves sous la forme $tab[id] = nom prenom (classe)
   *
   * @param array $option 'prof'=>id_prof pour ne rcuprer que les lves des classes de ce professeur
   */
  public static function listeElevesForSelect($option = NULL){

    $c = new Criteria();
    $c->add(UtilisateurPeer::RNE, $_SESSION['user']->getRne());
    if (!is_null($option) AND array_key_exists('prof', $option)){
      # On ne veut que les lves de ce professeur (en liaison avec ses classes)
      $c->add(UtilisateurPeer::CLASSE_ID, ClassePeer::listeClassesCeProfesseur($option['prof']), Criteria::IN);
    }
    $c->add(rolePeer::NOM, 'eleve', Criteria::EQUAL);
    $c->addAscendingOrderByColumn(UtilisateurPeer::CLASSE_ID);
    $c->addAscendingOrderByColumn(UtilisateurPeer::NOM);
    $c->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
    $liste = UtilisateurPeer::doSelectJoinrole($c);

    $tab = array();
    $tab['0'] = ' -- Liste des &eacute;l&egrave;ves -- ';
    foreach ($liste as $eleve){
      $tab[$eleve->getId()] = $eleve->getNom() . ' ' . $eleve->getPrenom() .' ('.$eleve->getClasse()->getNom().') ';
    }
    return $tab;
  } // listeElevesForSelect()

  /**
   * Renvoie un tableau php des professeurs/coordonateurs pour le select du formulaire
   *
   * @return array tab[utilisateur_id] = nom prenom
   */
  public static function listeProfesseursForSelect(){

    $cr = new Criteria();
    $cr->add(UtilisateurPeer::RNE, $_SESSION['user']->getRne());
    $criter1 = $cr->getNewCriterion(rolePeer::NOM, 'professeur');
    $criter2 = $cr->getNewCriterion(rolePeer::NOM, 'coordinateur');
    $criter1->addOr($criter2);
    $cr->add($criter1);
    $cr->addAscendingOrderByColumn(UtilisateurPeer::NOM);
    $cr->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
    $liste = UtilisateurPeer::doSelectJoinrole($cr);

    $tab = array();
    $tab[0] = ' -- Liste des professeurs -- ';
    foreach ($liste as $prof) {
      $tab[$prof->getId()] = $prof->getNom() . ' ' . $prof->getPrenom();
    }

    return $tab;
  } // listeProfesseursForSelect()

  /**
   * Construit un tableau php pour les classes en dur dans la mthode
   *
   * @return array tab[classe_id] = nom_classe
   */
  public static function listeClasseForSelect(){
    $tab = array();
    $tab['0'] = 'Aucune';
    $c = new Criteria();
    $c->add(ClassePeer::RNE, $_SESSION['user']->getRne());
    $c->addAscendingOrderByColumn(ClassePeer::NOM);
    $liste = ClassePeer::doSelect($c);

    foreach ($liste as $classe) {
      $tab[$classe->getId()] = $classe->getNom() . ' | ' . $classe->getNomlong();
    }

    return $tab;
  } // listeClasseForSelect()

  /**
   * Renvoie la liste des lves d'une classe ordonns par Nom, Prnom, date de naissance.
   *
   * @param string $classe 
   * @return array objects Utilisateur
   */
  public static function listeElevesCetteCLasse($classeid){

    if (!array_key_exists($classeid, self::listeClasseForSelect())){
      Die('Cette classe n\'existe pas ! - '.$classeid . '(C::UtilisateurPeer-M::listeElevesCetteCLasse');
    }else{

      $c = new Criteria();
      $c->add(UtilisateurPeer::RNE, $_SESSION['user']->getRne());
      $c->add(UtilisateurPeer::CLASSE_ID, $classeid);
      $c->addAscendingOrderByColumn(UtilisateurPeer::NOM);
      $c->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
      $c->addAscendingOrderByColumn(UtilisateurPeer::NAISSANCE);
      return UtilisateurPeer::doSelect($c);

    }

  } // listeElevesCetteCLasse()

  public static function listeElevesCeGroupe($groupeId){

    $c = new Criteria();
    $c->add(JGroupeElevePeer::GROUPE_ID, $groupeId);
    return JGroupeElevePeer::doSelect($c);

  } // listeElevesCeGroupe()

  /**
   * Liste des profeseurs de cette classe
   */
  public static function listeProfesseursCetteCLasseForSelect($classe_id){

    $c = new Criteria();
    $c->add(JProfesseurClassesPeer::CLASSE_ID, $classe_id);
    $liste = JProfesseurClassesPeer::doSelectJoinUtilisateur($c);

    $tab = array();
    $tab[0] = ' -- Liste des professeurs de cette classe -- ';
    foreach ($liste as $join) {
      $tab[$join->getUtilisateur()->getId()] = $join->getUtilisateur()->getNom() . ' '.$join->getUtilisateur()->getPrenom();
    }

    return $tab;

  } // listeProfesseursCetteCLasseForSelect()

} // UtilisateurPeer
