<?php

/**
 * Base class that represents a row from the 'bulletins' table.
 *
 * Liste des bulletins
 *
 * @package    competencesrb.om
 */
abstract class BaseBulletin extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        BulletinPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nom field.
	 * @var        string
	 */
	protected $nom;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the debut field.
	 * @var        int
	 */
	protected $debut;

	/**
	 * The value for the fin field.
	 * @var        int
	 */
	protected $fin;

	/**
	 * The value for the ferme field.
	 * Note: this column has a database default value of: 'N'
	 * @var        string
	 */
	protected $ferme;

	/**
	 * The value for the created_on field.
	 * @var        int
	 */
	protected $created_on;

	/**
	 * The value for the classe_id field.
	 * @var        int
	 */
	protected $classe_id;

	/**
	 * @var        Classe
	 */
	protected $aClasse;

	/**
	 * @var        array JBulletinTransversales[] Collection to store aggregation of JBulletinTransversales objects.
	 */
	protected $collJBulletinTransversaless;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJBulletinTransversaless.
	 */
	private $lastJBulletinTransversalesCriteria = null;

	/**
	 * @var        array Appreciation[] Collection to store aggregation of Appreciation objects.
	 */
	protected $collAppreciations;

	/**
	 * @var        Criteria The criteria used to select the current contents of collAppreciations.
	 */
	private $lastAppreciationCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseBulletin object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->ferme = 'N';
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table bulletins
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nom] column value.
	 * Nom du bulletin
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [debut] column value.
	 * Date de debut de la periode des bilans du bulletin
	 * @return     int
	 */
	public function getDebut()
	{
		return $this->debut;
	}

	/**
	 * Get the [fin] column value.
	 * Date de debut de la periode des bilans du bulletin
	 * @return     int
	 */
	public function getFin()
	{
		return $this->fin;
	}

	/**
	 * Get the [ferme] column value.
	 * si `ferme` est à O, les controle d'avant sont fermes aussi
	 * @return     string
	 */
	public function getFerme()
	{
		return $this->ferme;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation du bulletin
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Get the [classe_id] column value.
	 * classe concernee par ce bulletin
	 * @return     int
	 */
	public function getClasseId()
	{
		return $this->classe_id;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table bulletins
	 * @param      int $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = BulletinPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nom] column.
	 * Nom du bulletin
	 * @param      string $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v) {
			$this->nom = $v;
			$this->modifiedColumns[] = BulletinPeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = BulletinPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [debut] column.
	 * Date de debut de la periode des bilans du bulletin
	 * @param      int $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setDebut($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->debut !== $v) {
			$this->debut = $v;
			$this->modifiedColumns[] = BulletinPeer::DEBUT;
		}

		return $this;
	} // setDebut()

	/**
	 * Set the value of [fin] column.
	 * Date de debut de la periode des bilans du bulletin
	 * @param      int $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setFin($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->fin !== $v) {
			$this->fin = $v;
			$this->modifiedColumns[] = BulletinPeer::FIN;
		}

		return $this;
	} // setFin()

	/**
	 * Set the value of [ferme] column.
	 * si `ferme` est à O, les controle d'avant sont fermes aussi
	 * @param      string $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setFerme($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->ferme !== $v || $v === 'N') {
			$this->ferme = $v;
			$this->modifiedColumns[] = BulletinPeer::FERME;
		}

		return $this;
	} // setFerme()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation du bulletin
	 * @param      int $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v) {
			$this->created_on = $v;
			$this->modifiedColumns[] = BulletinPeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Set the value of [classe_id] column.
	 * classe concernee par ce bulletin
	 * @param      int $v new value
	 * @return     Bulletin The current object (for fluent API support)
	 */
	public function setClasseId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->classe_id !== $v) {
			$this->classe_id = $v;
			$this->modifiedColumns[] = BulletinPeer::CLASSE_ID;
		}

		if ($this->aClasse !== null && $this->aClasse->getId() !== $v) {
			$this->aClasse = null;
		}

		return $this;
	} // setClasseId()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(BulletinPeer::FERME))) {
				return false;
			}

			if ($this->ferme !== 'N') {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nom = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->rne = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->debut = ($row[$startcol + 3] !== null) ? (int) $row[$startcol + 3] : null;
			$this->fin = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->ferme = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->created_on = ($row[$startcol + 6] !== null) ? (int) $row[$startcol + 6] : null;
			$this->classe_id = ($row[$startcol + 7] !== null) ? (int) $row[$startcol + 7] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 8; // 8 = BulletinPeer::NUM_COLUMNS - BulletinPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Bulletin object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aClasse !== null && $this->classe_id !== $this->aClasse->getId()) {
			$this->aClasse = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(BulletinPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = BulletinPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aClasse = null;
			$this->collJBulletinTransversaless = null;
			$this->lastJBulletinTransversalesCriteria = null;

			$this->collAppreciations = null;
			$this->lastAppreciationCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(BulletinPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			BulletinPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(BulletinPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			BulletinPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aClasse !== null) {
				if ($this->aClasse->isModified() || $this->aClasse->isNew()) {
					$affectedRows += $this->aClasse->save($con);
				}
				$this->setClasse($this->aClasse);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = BulletinPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = BulletinPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += BulletinPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJBulletinTransversaless !== null) {
				foreach ($this->collJBulletinTransversaless as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collAppreciations !== null) {
				foreach ($this->collAppreciations as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aClasse !== null) {
				if (!$this->aClasse->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aClasse->getValidationFailures());
				}
			}


			if (($retval = BulletinPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJBulletinTransversaless !== null) {
					foreach ($this->collJBulletinTransversaless as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collAppreciations !== null) {
					foreach ($this->collAppreciations as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = BulletinPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNom();
				break;
			case 2:
				return $this->getRne();
				break;
			case 3:
				return $this->getDebut();
				break;
			case 4:
				return $this->getFin();
				break;
			case 5:
				return $this->getFerme();
				break;
			case 6:
				return $this->getCreatedOn();
				break;
			case 7:
				return $this->getClasseId();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = BulletinPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNom(),
			$keys[2] => $this->getRne(),
			$keys[3] => $this->getDebut(),
			$keys[4] => $this->getFin(),
			$keys[5] => $this->getFerme(),
			$keys[6] => $this->getCreatedOn(),
			$keys[7] => $this->getClasseId(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = BulletinPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNom($value);
				break;
			case 2:
				$this->setRne($value);
				break;
			case 3:
				$this->setDebut($value);
				break;
			case 4:
				$this->setFin($value);
				break;
			case 5:
				$this->setFerme($value);
				break;
			case 6:
				$this->setCreatedOn($value);
				break;
			case 7:
				$this->setClasseId($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = BulletinPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNom($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setRne($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setDebut($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setFin($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setFerme($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setCreatedOn($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setClasseId($arr[$keys[7]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(BulletinPeer::DATABASE_NAME);

		if ($this->isColumnModified(BulletinPeer::ID)) $criteria->add(BulletinPeer::ID, $this->id);
		if ($this->isColumnModified(BulletinPeer::NOM)) $criteria->add(BulletinPeer::NOM, $this->nom);
		if ($this->isColumnModified(BulletinPeer::RNE)) $criteria->add(BulletinPeer::RNE, $this->rne);
		if ($this->isColumnModified(BulletinPeer::DEBUT)) $criteria->add(BulletinPeer::DEBUT, $this->debut);
		if ($this->isColumnModified(BulletinPeer::FIN)) $criteria->add(BulletinPeer::FIN, $this->fin);
		if ($this->isColumnModified(BulletinPeer::FERME)) $criteria->add(BulletinPeer::FERME, $this->ferme);
		if ($this->isColumnModified(BulletinPeer::CREATED_ON)) $criteria->add(BulletinPeer::CREATED_ON, $this->created_on);
		if ($this->isColumnModified(BulletinPeer::CLASSE_ID)) $criteria->add(BulletinPeer::CLASSE_ID, $this->classe_id);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(BulletinPeer::DATABASE_NAME);

		$criteria->add(BulletinPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Bulletin (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNom($this->nom);

		$copyObj->setRne($this->rne);

		$copyObj->setDebut($this->debut);

		$copyObj->setFin($this->fin);

		$copyObj->setFerme($this->ferme);

		$copyObj->setCreatedOn($this->created_on);

		$copyObj->setClasseId($this->classe_id);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJBulletinTransversaless() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJBulletinTransversales($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getAppreciations() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addAppreciation($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Bulletin Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     BulletinPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new BulletinPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Classe object.
	 *
	 * @param      Classe $v
	 * @return     Bulletin The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setClasse(Classe $v = null)
	{
		if ($v === null) {
			$this->setClasseId(NULL);
		} else {
			$this->setClasseId($v->getId());
		}

		$this->aClasse = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Classe object, it will not be re-added.
		if ($v !== null) {
			$v->addBulletin($this);
		}

		return $this;
	}


	/**
	 * Get the associated Classe object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Classe The associated Classe object.
	 * @throws     PropelException
	 */
	public function getClasse(PropelPDO $con = null)
	{
		if ($this->aClasse === null && ($this->classe_id !== null)) {
			$this->aClasse = ClassePeer::retrieveByPK($this->classe_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aClasse->addBulletins($this);
			 */
		}
		return $this->aClasse;
	}

	/**
	 * Clears out the collJBulletinTransversaless collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJBulletinTransversaless()
	 */
	public function clearJBulletinTransversaless()
	{
		$this->collJBulletinTransversaless = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJBulletinTransversaless collection (array).
	 *
	 * By default this just sets the collJBulletinTransversaless collection to an empty array (like clearcollJBulletinTransversaless());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJBulletinTransversaless()
	{
		$this->collJBulletinTransversaless = array();
	}

	/**
	 * Gets an array of JBulletinTransversales objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Bulletin has previously been saved, it will retrieve
	 * related JBulletinTransversaless from storage. If this Bulletin is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JBulletinTransversales[]
	 * @throws     PropelException
	 */
	public function getJBulletinTransversaless($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
			   $this->collJBulletinTransversaless = array();
			} else {

				$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

				JBulletinTransversalesPeer::addSelectColumns($criteria);
				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

				JBulletinTransversalesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
					$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;
		return $this->collJBulletinTransversaless;
	}

	/**
	 * Returns the number of related JBulletinTransversales objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JBulletinTransversales objects.
	 * @throws     PropelException
	 */
	public function countJBulletinTransversaless(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

				$count = JBulletinTransversalesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

				if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
					$count = JBulletinTransversalesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJBulletinTransversaless);
				}
			} else {
				$count = count($this->collJBulletinTransversaless);
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JBulletinTransversales object to this object
	 * through the JBulletinTransversales foreign key attribute.
	 *
	 * @param      JBulletinTransversales $l JBulletinTransversales
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJBulletinTransversales(JBulletinTransversales $l)
	{
		if ($this->collJBulletinTransversaless === null) {
			$this->initJBulletinTransversaless();
		}
		if (!in_array($l, $this->collJBulletinTransversaless, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJBulletinTransversaless, $l);
			$l->setBulletin($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Bulletin is new, it will return
	 * an empty collection; or if this Bulletin has previously
	 * been saved, it will retrieve related JBulletinTransversaless from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Bulletin.
	 */
	public function getJBulletinTransversalessJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
				$this->collJBulletinTransversaless = array();
			} else {

				$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JBulletinTransversalesPeer::BULLETIN_ID, $this->id);

			if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;

		return $this->collJBulletinTransversaless;
	}

	/**
	 * Clears out the collAppreciations collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addAppreciations()
	 */
	public function clearAppreciations()
	{
		$this->collAppreciations = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collAppreciations collection (array).
	 *
	 * By default this just sets the collAppreciations collection to an empty array (like clearcollAppreciations());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initAppreciations()
	{
		$this->collAppreciations = array();
	}

	/**
	 * Gets an array of Appreciation objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Bulletin has previously been saved, it will retrieve
	 * related Appreciations from storage. If this Bulletin is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Appreciation[]
	 * @throws     PropelException
	 */
	public function getAppreciations($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collAppreciations === null) {
			if ($this->isNew()) {
			   $this->collAppreciations = array();
			} else {

				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				AppreciationPeer::addSelectColumns($criteria);
				$this->collAppreciations = AppreciationPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				AppreciationPeer::addSelectColumns($criteria);
				if (!isset($this->lastAppreciationCriteria) || !$this->lastAppreciationCriteria->equals($criteria)) {
					$this->collAppreciations = AppreciationPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastAppreciationCriteria = $criteria;
		return $this->collAppreciations;
	}

	/**
	 * Returns the number of related Appreciation objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Appreciation objects.
	 * @throws     PropelException
	 */
	public function countAppreciations(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collAppreciations === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				$count = AppreciationPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				if (!isset($this->lastAppreciationCriteria) || !$this->lastAppreciationCriteria->equals($criteria)) {
					$count = AppreciationPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collAppreciations);
				}
			} else {
				$count = count($this->collAppreciations);
			}
		}
		$this->lastAppreciationCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Appreciation object to this object
	 * through the Appreciation foreign key attribute.
	 *
	 * @param      Appreciation $l Appreciation
	 * @return     void
	 * @throws     PropelException
	 */
	public function addAppreciation(Appreciation $l)
	{
		if ($this->collAppreciations === null) {
			$this->initAppreciations();
		}
		if (!in_array($l, $this->collAppreciations, true)) { // only add it if the **same** object is not already associated
			array_push($this->collAppreciations, $l);
			$l->setBulletin($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Bulletin is new, it will return
	 * an empty collection; or if this Bulletin has previously
	 * been saved, it will retrieve related Appreciations from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Bulletin.
	 */
	public function getAppreciationsJoinUtilisateurRelatedByProfesseurId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collAppreciations === null) {
			if ($this->isNew()) {
				$this->collAppreciations = array();
			} else {

				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				$this->collAppreciations = AppreciationPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

			if (!isset($this->lastAppreciationCriteria) || !$this->lastAppreciationCriteria->equals($criteria)) {
				$this->collAppreciations = AppreciationPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		}
		$this->lastAppreciationCriteria = $criteria;

		return $this->collAppreciations;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Bulletin is new, it will return
	 * an empty collection; or if this Bulletin has previously
	 * been saved, it will retrieve related Appreciations from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Bulletin.
	 */
	public function getAppreciationsJoinUtilisateurRelatedByEleveId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(BulletinPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collAppreciations === null) {
			if ($this->isNew()) {
				$this->collAppreciations = array();
			} else {

				$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

				$this->collAppreciations = AppreciationPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(AppreciationPeer::BULLETIN_ID, $this->id);

			if (!isset($this->lastAppreciationCriteria) || !$this->lastAppreciationCriteria->equals($criteria)) {
				$this->collAppreciations = AppreciationPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		}
		$this->lastAppreciationCriteria = $criteria;

		return $this->collAppreciations;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJBulletinTransversaless) {
				foreach ((array) $this->collJBulletinTransversaless as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collAppreciations) {
				foreach ((array) $this->collAppreciations as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJBulletinTransversaless = null;
		$this->collAppreciations = null;
			$this->aClasse = null;
	}

} // BaseBulletin
