<?php

/**
 * Base class that represents a row from the 'classes' table.
 *
 * liste des classes
 *
 * @package    competencesrb.om
 */
abstract class BaseClasse extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        ClassePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nom field.
	 * @var        string
	 */
	protected $nom;

	/**
	 * The value for the nomlong field.
	 * @var        string
	 */
	protected $nomlong;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * @var        etablissement
	 */
	protected $aetablissement;

	/**
	 * @var        array Utilisateur[] Collection to store aggregation of Utilisateur objects.
	 */
	protected $collUtilisateurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collUtilisateurs.
	 */
	private $lastUtilisateurCriteria = null;

	/**
	 * @var        array JProfesseurClasses[] Collection to store aggregation of JProfesseurClasses objects.
	 */
	protected $collJProfesseurClassess;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJProfesseurClassess.
	 */
	private $lastJProfesseurClassesCriteria = null;

	/**
	 * @var        array JProfesseurPrincipalClasses[] Collection to store aggregation of JProfesseurPrincipalClasses objects.
	 */
	protected $collJProfesseurPrincipalClassess;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJProfesseurPrincipalClassess.
	 */
	private $lastJProfesseurPrincipalClassesCriteria = null;

	/**
	 * @var        array Bulletin[] Collection to store aggregation of Bulletin objects.
	 */
	protected $collBulletins;

	/**
	 * @var        Criteria The criteria used to select the current contents of collBulletins.
	 */
	private $lastBulletinCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseClasse object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table classes
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nom] column value.
	 * nom de la classe
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Get the [nomlong] column value.
	 * nomlong de la classe
	 * @return     string
	 */
	public function getNomlong()
	{
		return $this->nomlong;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table classes
	 * @param      int $v new value
	 * @return     Classe The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = ClassePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nom] column.
	 * nom de la classe
	 * @param      string $v new value
	 * @return     Classe The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v) {
			$this->nom = $v;
			$this->modifiedColumns[] = ClassePeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Set the value of [nomlong] column.
	 * nomlong de la classe
	 * @param      string $v new value
	 * @return     Classe The current object (for fluent API support)
	 */
	public function setNomlong($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomlong !== $v) {
			$this->nomlong = $v;
			$this->modifiedColumns[] = ClassePeer::NOMLONG;
		}

		return $this;
	} // setNomlong()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     Classe The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = ClassePeer::RNE;
		}

		if ($this->aetablissement !== null && $this->aetablissement->getRne() !== $v) {
			$this->aetablissement = null;
		}

		return $this;
	} // setRne()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nom = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->nomlong = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->rne = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 4; // 4 = ClassePeer::NUM_COLUMNS - ClassePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Classe object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aetablissement !== null && $this->rne !== $this->aetablissement->getRne()) {
			$this->aetablissement = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ClassePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = ClassePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aetablissement = null;
			$this->collUtilisateurs = null;
			$this->lastUtilisateurCriteria = null;

			$this->collJProfesseurClassess = null;
			$this->lastJProfesseurClassesCriteria = null;

			$this->collJProfesseurPrincipalClassess = null;
			$this->lastJProfesseurPrincipalClassesCriteria = null;

			$this->collBulletins = null;
			$this->lastBulletinCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ClassePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			ClassePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ClassePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			ClassePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aetablissement !== null) {
				if ($this->aetablissement->isModified() || $this->aetablissement->isNew()) {
					$affectedRows += $this->aetablissement->save($con);
				}
				$this->setetablissement($this->aetablissement);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = ClassePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = ClassePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += ClassePeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collUtilisateurs !== null) {
				foreach ($this->collUtilisateurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJProfesseurClassess !== null) {
				foreach ($this->collJProfesseurClassess as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJProfesseurPrincipalClassess !== null) {
				foreach ($this->collJProfesseurPrincipalClassess as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collBulletins !== null) {
				foreach ($this->collBulletins as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aetablissement !== null) {
				if (!$this->aetablissement->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aetablissement->getValidationFailures());
				}
			}


			if (($retval = ClassePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collUtilisateurs !== null) {
					foreach ($this->collUtilisateurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJProfesseurClassess !== null) {
					foreach ($this->collJProfesseurClassess as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJProfesseurPrincipalClassess !== null) {
					foreach ($this->collJProfesseurPrincipalClassess as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collBulletins !== null) {
					foreach ($this->collBulletins as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = ClassePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNom();
				break;
			case 2:
				return $this->getNomlong();
				break;
			case 3:
				return $this->getRne();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = ClassePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNom(),
			$keys[2] => $this->getNomlong(),
			$keys[3] => $this->getRne(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = ClassePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNom($value);
				break;
			case 2:
				$this->setNomlong($value);
				break;
			case 3:
				$this->setRne($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = ClassePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNom($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setNomlong($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setRne($arr[$keys[3]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(ClassePeer::DATABASE_NAME);

		if ($this->isColumnModified(ClassePeer::ID)) $criteria->add(ClassePeer::ID, $this->id);
		if ($this->isColumnModified(ClassePeer::NOM)) $criteria->add(ClassePeer::NOM, $this->nom);
		if ($this->isColumnModified(ClassePeer::NOMLONG)) $criteria->add(ClassePeer::NOMLONG, $this->nomlong);
		if ($this->isColumnModified(ClassePeer::RNE)) $criteria->add(ClassePeer::RNE, $this->rne);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(ClassePeer::DATABASE_NAME);

		$criteria->add(ClassePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Classe (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNom($this->nom);

		$copyObj->setNomlong($this->nomlong);

		$copyObj->setRne($this->rne);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getUtilisateurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addUtilisateur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJProfesseurClassess() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJProfesseurClasses($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJProfesseurPrincipalClassess() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJProfesseurPrincipalClasses($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getBulletins() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addBulletin($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Classe Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     ClassePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new ClassePeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a etablissement object.
	 *
	 * @param      etablissement $v
	 * @return     Classe The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setetablissement(etablissement $v = null)
	{
		if ($v === null) {
			$this->setRne(NULL);
		} else {
			$this->setRne($v->getRne());
		}

		$this->aetablissement = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the etablissement object, it will not be re-added.
		if ($v !== null) {
			$v->addClasse($this);
		}

		return $this;
	}


	/**
	 * Get the associated etablissement object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     etablissement The associated etablissement object.
	 * @throws     PropelException
	 */
	public function getetablissement(PropelPDO $con = null)
	{
		if ($this->aetablissement === null && (($this->rne !== "" && $this->rne !== null))) {
			$this->aetablissement = etablissementPeer::retrieveByPK($this->rne, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aetablissement->addClasses($this);
			 */
		}
		return $this->aetablissement;
	}

	/**
	 * Clears out the collUtilisateurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addUtilisateurs()
	 */
	public function clearUtilisateurs()
	{
		$this->collUtilisateurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collUtilisateurs collection (array).
	 *
	 * By default this just sets the collUtilisateurs collection to an empty array (like clearcollUtilisateurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initUtilisateurs()
	{
		$this->collUtilisateurs = array();
	}

	/**
	 * Gets an array of Utilisateur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Classe has previously been saved, it will retrieve
	 * related Utilisateurs from storage. If this Classe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Utilisateur[]
	 * @throws     PropelException
	 */
	public function getUtilisateurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
			   $this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				UtilisateurPeer::addSelectColumns($criteria);
				$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				UtilisateurPeer::addSelectColumns($criteria);
				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $this->collUtilisateurs;
	}

	/**
	 * Returns the number of related Utilisateur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Utilisateur objects.
	 * @throws     PropelException
	 */
	public function countUtilisateurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				$count = UtilisateurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$count = UtilisateurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collUtilisateurs);
				}
			} else {
				$count = count($this->collUtilisateurs);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Utilisateur object to this object
	 * through the Utilisateur foreign key attribute.
	 *
	 * @param      Utilisateur $l Utilisateur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addUtilisateur(Utilisateur $l)
	{
		if ($this->collUtilisateurs === null) {
			$this->initUtilisateurs();
		}
		if (!in_array($l, $this->collUtilisateurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collUtilisateurs, $l);
			$l->setClasse($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Classe is new, it will return
	 * an empty collection; or if this Classe has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Classe.
	 */
	public function getUtilisateursJoinetablissement($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Classe is new, it will return
	 * an empty collection; or if this Classe has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Classe.
	 */
	public function getUtilisateursJoinrole($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Classe is new, it will return
	 * an empty collection; or if this Classe has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Classe.
	 */
	public function getUtilisateursJoinMatiere($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::CLASSE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}

	/**
	 * Clears out the collJProfesseurClassess collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJProfesseurClassess()
	 */
	public function clearJProfesseurClassess()
	{
		$this->collJProfesseurClassess = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJProfesseurClassess collection (array).
	 *
	 * By default this just sets the collJProfesseurClassess collection to an empty array (like clearcollJProfesseurClassess());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJProfesseurClassess()
	{
		$this->collJProfesseurClassess = array();
	}

	/**
	 * Gets an array of JProfesseurClasses objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Classe has previously been saved, it will retrieve
	 * related JProfesseurClassess from storage. If this Classe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JProfesseurClasses[]
	 * @throws     PropelException
	 */
	public function getJProfesseurClassess($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJProfesseurClassess === null) {
			if ($this->isNew()) {
			   $this->collJProfesseurClassess = array();
			} else {

				$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

				JProfesseurClassesPeer::addSelectColumns($criteria);
				$this->collJProfesseurClassess = JProfesseurClassesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

				JProfesseurClassesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJProfesseurClassesCriteria) || !$this->lastJProfesseurClassesCriteria->equals($criteria)) {
					$this->collJProfesseurClassess = JProfesseurClassesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJProfesseurClassesCriteria = $criteria;
		return $this->collJProfesseurClassess;
	}

	/**
	 * Returns the number of related JProfesseurClasses objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JProfesseurClasses objects.
	 * @throws     PropelException
	 */
	public function countJProfesseurClassess(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJProfesseurClassess === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

				$count = JProfesseurClassesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

				if (!isset($this->lastJProfesseurClassesCriteria) || !$this->lastJProfesseurClassesCriteria->equals($criteria)) {
					$count = JProfesseurClassesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJProfesseurClassess);
				}
			} else {
				$count = count($this->collJProfesseurClassess);
			}
		}
		$this->lastJProfesseurClassesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JProfesseurClasses object to this object
	 * through the JProfesseurClasses foreign key attribute.
	 *
	 * @param      JProfesseurClasses $l JProfesseurClasses
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJProfesseurClasses(JProfesseurClasses $l)
	{
		if ($this->collJProfesseurClassess === null) {
			$this->initJProfesseurClassess();
		}
		if (!in_array($l, $this->collJProfesseurClassess, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJProfesseurClassess, $l);
			$l->setClasse($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Classe is new, it will return
	 * an empty collection; or if this Classe has previously
	 * been saved, it will retrieve related JProfesseurClassess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Classe.
	 */
	public function getJProfesseurClassessJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJProfesseurClassess === null) {
			if ($this->isNew()) {
				$this->collJProfesseurClassess = array();
			} else {

				$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

				$this->collJProfesseurClassess = JProfesseurClassesPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JProfesseurClassesPeer::CLASSE_ID, $this->id);

			if (!isset($this->lastJProfesseurClassesCriteria) || !$this->lastJProfesseurClassesCriteria->equals($criteria)) {
				$this->collJProfesseurClassess = JProfesseurClassesPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJProfesseurClassesCriteria = $criteria;

		return $this->collJProfesseurClassess;
	}

	/**
	 * Clears out the collJProfesseurPrincipalClassess collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJProfesseurPrincipalClassess()
	 */
	public function clearJProfesseurPrincipalClassess()
	{
		$this->collJProfesseurPrincipalClassess = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJProfesseurPrincipalClassess collection (array).
	 *
	 * By default this just sets the collJProfesseurPrincipalClassess collection to an empty array (like clearcollJProfesseurPrincipalClassess());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJProfesseurPrincipalClassess()
	{
		$this->collJProfesseurPrincipalClassess = array();
	}

	/**
	 * Gets an array of JProfesseurPrincipalClasses objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Classe has previously been saved, it will retrieve
	 * related JProfesseurPrincipalClassess from storage. If this Classe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JProfesseurPrincipalClasses[]
	 * @throws     PropelException
	 */
	public function getJProfesseurPrincipalClassess($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJProfesseurPrincipalClassess === null) {
			if ($this->isNew()) {
			   $this->collJProfesseurPrincipalClassess = array();
			} else {

				$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

				JProfesseurPrincipalClassesPeer::addSelectColumns($criteria);
				$this->collJProfesseurPrincipalClassess = JProfesseurPrincipalClassesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

				JProfesseurPrincipalClassesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJProfesseurPrincipalClassesCriteria) || !$this->lastJProfesseurPrincipalClassesCriteria->equals($criteria)) {
					$this->collJProfesseurPrincipalClassess = JProfesseurPrincipalClassesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJProfesseurPrincipalClassesCriteria = $criteria;
		return $this->collJProfesseurPrincipalClassess;
	}

	/**
	 * Returns the number of related JProfesseurPrincipalClasses objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JProfesseurPrincipalClasses objects.
	 * @throws     PropelException
	 */
	public function countJProfesseurPrincipalClassess(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJProfesseurPrincipalClassess === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

				$count = JProfesseurPrincipalClassesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

				if (!isset($this->lastJProfesseurPrincipalClassesCriteria) || !$this->lastJProfesseurPrincipalClassesCriteria->equals($criteria)) {
					$count = JProfesseurPrincipalClassesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJProfesseurPrincipalClassess);
				}
			} else {
				$count = count($this->collJProfesseurPrincipalClassess);
			}
		}
		$this->lastJProfesseurPrincipalClassesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JProfesseurPrincipalClasses object to this object
	 * through the JProfesseurPrincipalClasses foreign key attribute.
	 *
	 * @param      JProfesseurPrincipalClasses $l JProfesseurPrincipalClasses
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJProfesseurPrincipalClasses(JProfesseurPrincipalClasses $l)
	{
		if ($this->collJProfesseurPrincipalClassess === null) {
			$this->initJProfesseurPrincipalClassess();
		}
		if (!in_array($l, $this->collJProfesseurPrincipalClassess, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJProfesseurPrincipalClassess, $l);
			$l->setClasse($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Classe is new, it will return
	 * an empty collection; or if this Classe has previously
	 * been saved, it will retrieve related JProfesseurPrincipalClassess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Classe.
	 */
	public function getJProfesseurPrincipalClassessJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJProfesseurPrincipalClassess === null) {
			if ($this->isNew()) {
				$this->collJProfesseurPrincipalClassess = array();
			} else {

				$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

				$this->collJProfesseurPrincipalClassess = JProfesseurPrincipalClassesPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JProfesseurPrincipalClassesPeer::CLASSE_ID, $this->id);

			if (!isset($this->lastJProfesseurPrincipalClassesCriteria) || !$this->lastJProfesseurPrincipalClassesCriteria->equals($criteria)) {
				$this->collJProfesseurPrincipalClassess = JProfesseurPrincipalClassesPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJProfesseurPrincipalClassesCriteria = $criteria;

		return $this->collJProfesseurPrincipalClassess;
	}

	/**
	 * Clears out the collBulletins collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addBulletins()
	 */
	public function clearBulletins()
	{
		$this->collBulletins = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collBulletins collection (array).
	 *
	 * By default this just sets the collBulletins collection to an empty array (like clearcollBulletins());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initBulletins()
	{
		$this->collBulletins = array();
	}

	/**
	 * Gets an array of Bulletin objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Classe has previously been saved, it will retrieve
	 * related Bulletins from storage. If this Classe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Bulletin[]
	 * @throws     PropelException
	 */
	public function getBulletins($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBulletins === null) {
			if ($this->isNew()) {
			   $this->collBulletins = array();
			} else {

				$criteria->add(BulletinPeer::CLASSE_ID, $this->id);

				BulletinPeer::addSelectColumns($criteria);
				$this->collBulletins = BulletinPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(BulletinPeer::CLASSE_ID, $this->id);

				BulletinPeer::addSelectColumns($criteria);
				if (!isset($this->lastBulletinCriteria) || !$this->lastBulletinCriteria->equals($criteria)) {
					$this->collBulletins = BulletinPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastBulletinCriteria = $criteria;
		return $this->collBulletins;
	}

	/**
	 * Returns the number of related Bulletin objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Bulletin objects.
	 * @throws     PropelException
	 */
	public function countBulletins(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ClassePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collBulletins === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(BulletinPeer::CLASSE_ID, $this->id);

				$count = BulletinPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(BulletinPeer::CLASSE_ID, $this->id);

				if (!isset($this->lastBulletinCriteria) || !$this->lastBulletinCriteria->equals($criteria)) {
					$count = BulletinPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collBulletins);
				}
			} else {
				$count = count($this->collBulletins);
			}
		}
		$this->lastBulletinCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Bulletin object to this object
	 * through the Bulletin foreign key attribute.
	 *
	 * @param      Bulletin $l Bulletin
	 * @return     void
	 * @throws     PropelException
	 */
	public function addBulletin(Bulletin $l)
	{
		if ($this->collBulletins === null) {
			$this->initBulletins();
		}
		if (!in_array($l, $this->collBulletins, true)) { // only add it if the **same** object is not already associated
			array_push($this->collBulletins, $l);
			$l->setClasse($this);
		}
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collUtilisateurs) {
				foreach ((array) $this->collUtilisateurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJProfesseurClassess) {
				foreach ((array) $this->collJProfesseurClassess as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJProfesseurPrincipalClassess) {
				foreach ((array) $this->collJProfesseurPrincipalClassess as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collBulletins) {
				foreach ((array) $this->collBulletins as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collUtilisateurs = null;
		$this->collJProfesseurClassess = null;
		$this->collJProfesseurPrincipalClassess = null;
		$this->collBulletins = null;
			$this->aetablissement = null;
	}

} // BaseClasse
