<?php

/**
 * Base class that represents a row from the 'cptcegrps' table.
 *
 * Les principaux themes de competence du tronc commun
 *
 * @package    competencesrb.om
 */
abstract class BaseCompetenceGrp extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        CompetenceGrpPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the ordre field.
	 * @var        int
	 */
	protected $ordre;

	/**
	 * The value for the nom field.
	 * @var        string
	 */
	protected $nom;

	/**
	 * @var        array Competence[] Collection to store aggregation of Competence objects.
	 */
	protected $collCompetences;

	/**
	 * @var        Criteria The criteria used to select the current contents of collCompetences.
	 */
	private $lastCompetenceCriteria = null;

	/**
	 * @var        array JCompetencegrpUtilisateur[] Collection to store aggregation of JCompetencegrpUtilisateur objects.
	 */
	protected $collJCompetencegrpUtilisateurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetencegrpUtilisateurs.
	 */
	private $lastJCompetencegrpUtilisateurCriteria = null;

	/**
	 * @var        array JAttestationItem[] Collection to store aggregation of JAttestationItem objects.
	 */
	protected $collJAttestationItems;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJAttestationItems.
	 */
	private $lastJAttestationItemCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseCompetenceGrp object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table cptcegrps
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [ordre] column value.
	 * Ordre d'affichage de ces groupes de compétences (tronc commun)
	 * @return     int
	 */
	public function getOrdre()
	{
		return $this->ordre;
	}

	/**
	 * Get the [nom] column value.
	 * Nom du grp
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table cptcegrps
	 * @param      int $v new value
	 * @return     CompetenceGrp The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = CompetenceGrpPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [ordre] column.
	 * Ordre d'affichage de ces groupes de compétences (tronc commun)
	 * @param      int $v new value
	 * @return     CompetenceGrp The current object (for fluent API support)
	 */
	public function setOrdre($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->ordre !== $v) {
			$this->ordre = $v;
			$this->modifiedColumns[] = CompetenceGrpPeer::ORDRE;
		}

		return $this;
	} // setOrdre()

	/**
	 * Set the value of [nom] column.
	 * Nom du grp
	 * @param      string $v new value
	 * @return     CompetenceGrp The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v) {
			$this->nom = $v;
			$this->modifiedColumns[] = CompetenceGrpPeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->ordre = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->nom = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 3; // 3 = CompetenceGrpPeer::NUM_COLUMNS - CompetenceGrpPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating CompetenceGrp object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetenceGrpPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = CompetenceGrpPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->collCompetences = null;
			$this->lastCompetenceCriteria = null;

			$this->collJCompetencegrpUtilisateurs = null;
			$this->lastJCompetencegrpUtilisateurCriteria = null;

			$this->collJAttestationItems = null;
			$this->lastJAttestationItemCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetenceGrpPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			CompetenceGrpPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetenceGrpPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			CompetenceGrpPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			if ($this->isNew() ) {
				$this->modifiedColumns[] = CompetenceGrpPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = CompetenceGrpPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += CompetenceGrpPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collCompetences !== null) {
				foreach ($this->collCompetences as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetencegrpUtilisateurs !== null) {
				foreach ($this->collJCompetencegrpUtilisateurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJAttestationItems !== null) {
				foreach ($this->collJAttestationItems as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			if (($retval = CompetenceGrpPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collCompetences !== null) {
					foreach ($this->collCompetences as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetencegrpUtilisateurs !== null) {
					foreach ($this->collJCompetencegrpUtilisateurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJAttestationItems !== null) {
					foreach ($this->collJAttestationItems as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = CompetenceGrpPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getOrdre();
				break;
			case 2:
				return $this->getNom();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = CompetenceGrpPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getOrdre(),
			$keys[2] => $this->getNom(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = CompetenceGrpPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setOrdre($value);
				break;
			case 2:
				$this->setNom($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = CompetenceGrpPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setOrdre($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setNom($arr[$keys[2]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);

		if ($this->isColumnModified(CompetenceGrpPeer::ID)) $criteria->add(CompetenceGrpPeer::ID, $this->id);
		if ($this->isColumnModified(CompetenceGrpPeer::ORDRE)) $criteria->add(CompetenceGrpPeer::ORDRE, $this->ordre);
		if ($this->isColumnModified(CompetenceGrpPeer::NOM)) $criteria->add(CompetenceGrpPeer::NOM, $this->nom);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);

		$criteria->add(CompetenceGrpPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of CompetenceGrp (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setOrdre($this->ordre);

		$copyObj->setNom($this->nom);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getCompetences() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addCompetence($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetencegrpUtilisateurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetencegrpUtilisateur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJAttestationItems() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJAttestationItem($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     CompetenceGrp Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     CompetenceGrpPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new CompetenceGrpPeer();
		}
		return self::$peer;
	}

	/**
	 * Clears out the collCompetences collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addCompetences()
	 */
	public function clearCompetences()
	{
		$this->collCompetences = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collCompetences collection (array).
	 *
	 * By default this just sets the collCompetences collection to an empty array (like clearcollCompetences());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initCompetences()
	{
		$this->collCompetences = array();
	}

	/**
	 * Gets an array of Competence objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp has previously been saved, it will retrieve
	 * related Competences from storage. If this CompetenceGrp is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Competence[]
	 * @throws     PropelException
	 */
	public function getCompetences($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetences === null) {
			if ($this->isNew()) {
			   $this->collCompetences = array();
			} else {

				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				CompetencePeer::addSelectColumns($criteria);
				$this->collCompetences = CompetencePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				CompetencePeer::addSelectColumns($criteria);
				if (!isset($this->lastCompetenceCriteria) || !$this->lastCompetenceCriteria->equals($criteria)) {
					$this->collCompetences = CompetencePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastCompetenceCriteria = $criteria;
		return $this->collCompetences;
	}

	/**
	 * Returns the number of related Competence objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Competence objects.
	 * @throws     PropelException
	 */
	public function countCompetences(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collCompetences === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				$count = CompetencePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				if (!isset($this->lastCompetenceCriteria) || !$this->lastCompetenceCriteria->equals($criteria)) {
					$count = CompetencePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collCompetences);
				}
			} else {
				$count = count($this->collCompetences);
			}
		}
		$this->lastCompetenceCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Competence object to this object
	 * through the Competence foreign key attribute.
	 *
	 * @param      Competence $l Competence
	 * @return     void
	 * @throws     PropelException
	 */
	public function addCompetence(Competence $l)
	{
		if ($this->collCompetences === null) {
			$this->initCompetences();
		}
		if (!in_array($l, $this->collCompetences, true)) { // only add it if the **same** object is not already associated
			array_push($this->collCompetences, $l);
			$l->setCompetenceGrp($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp is new, it will return
	 * an empty collection; or if this CompetenceGrp has previously
	 * been saved, it will retrieve related Competences from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in CompetenceGrp.
	 */
	public function getCompetencesJoinCompetenceRelatedByCompetenceId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetences === null) {
			if ($this->isNew()) {
				$this->collCompetences = array();
			} else {

				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				$this->collCompetences = CompetencePeer::doSelectJoinCompetenceRelatedByCompetenceId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

			if (!isset($this->lastCompetenceCriteria) || !$this->lastCompetenceCriteria->equals($criteria)) {
				$this->collCompetences = CompetencePeer::doSelectJoinCompetenceRelatedByCompetenceId($criteria, $con, $join_behavior);
			}
		}
		$this->lastCompetenceCriteria = $criteria;

		return $this->collCompetences;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp is new, it will return
	 * an empty collection; or if this CompetenceGrp has previously
	 * been saved, it will retrieve related Competences from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in CompetenceGrp.
	 */
	public function getCompetencesJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetences === null) {
			if ($this->isNew()) {
				$this->collCompetences = array();
			} else {

				$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

				$this->collCompetences = CompetencePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(CompetencePeer::CPTCEGRP_ID, $this->id);

			if (!isset($this->lastCompetenceCriteria) || !$this->lastCompetenceCriteria->equals($criteria)) {
				$this->collCompetences = CompetencePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastCompetenceCriteria = $criteria;

		return $this->collCompetences;
	}

	/**
	 * Clears out the collJCompetencegrpUtilisateurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetencegrpUtilisateurs()
	 */
	public function clearJCompetencegrpUtilisateurs()
	{
		$this->collJCompetencegrpUtilisateurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetencegrpUtilisateurs collection (array).
	 *
	 * By default this just sets the collJCompetencegrpUtilisateurs collection to an empty array (like clearcollJCompetencegrpUtilisateurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetencegrpUtilisateurs()
	{
		$this->collJCompetencegrpUtilisateurs = array();
	}

	/**
	 * Gets an array of JCompetencegrpUtilisateur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp has previously been saved, it will retrieve
	 * related JCompetencegrpUtilisateurs from storage. If this CompetenceGrp is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetencegrpUtilisateur[]
	 * @throws     PropelException
	 */
	public function getJCompetencegrpUtilisateurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetencegrpUtilisateurs === null) {
			if ($this->isNew()) {
			   $this->collJCompetencegrpUtilisateurs = array();
			} else {

				$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

				JCompetencegrpUtilisateurPeer::addSelectColumns($criteria);
				$this->collJCompetencegrpUtilisateurs = JCompetencegrpUtilisateurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

				JCompetencegrpUtilisateurPeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetencegrpUtilisateurCriteria) || !$this->lastJCompetencegrpUtilisateurCriteria->equals($criteria)) {
					$this->collJCompetencegrpUtilisateurs = JCompetencegrpUtilisateurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetencegrpUtilisateurCriteria = $criteria;
		return $this->collJCompetencegrpUtilisateurs;
	}

	/**
	 * Returns the number of related JCompetencegrpUtilisateur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetencegrpUtilisateur objects.
	 * @throws     PropelException
	 */
	public function countJCompetencegrpUtilisateurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetencegrpUtilisateurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

				$count = JCompetencegrpUtilisateurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

				if (!isset($this->lastJCompetencegrpUtilisateurCriteria) || !$this->lastJCompetencegrpUtilisateurCriteria->equals($criteria)) {
					$count = JCompetencegrpUtilisateurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetencegrpUtilisateurs);
				}
			} else {
				$count = count($this->collJCompetencegrpUtilisateurs);
			}
		}
		$this->lastJCompetencegrpUtilisateurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetencegrpUtilisateur object to this object
	 * through the JCompetencegrpUtilisateur foreign key attribute.
	 *
	 * @param      JCompetencegrpUtilisateur $l JCompetencegrpUtilisateur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetencegrpUtilisateur(JCompetencegrpUtilisateur $l)
	{
		if ($this->collJCompetencegrpUtilisateurs === null) {
			$this->initJCompetencegrpUtilisateurs();
		}
		if (!in_array($l, $this->collJCompetencegrpUtilisateurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetencegrpUtilisateurs, $l);
			$l->setCompetenceGrp($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp is new, it will return
	 * an empty collection; or if this CompetenceGrp has previously
	 * been saved, it will retrieve related JCompetencegrpUtilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in CompetenceGrp.
	 */
	public function getJCompetencegrpUtilisateursJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetencegrpUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collJCompetencegrpUtilisateurs = array();
			} else {

				$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

				$this->collJCompetencegrpUtilisateurs = JCompetencegrpUtilisateurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetencegrpUtilisateurPeer::CPTCEGRP_ID, $this->id);

			if (!isset($this->lastJCompetencegrpUtilisateurCriteria) || !$this->lastJCompetencegrpUtilisateurCriteria->equals($criteria)) {
				$this->collJCompetencegrpUtilisateurs = JCompetencegrpUtilisateurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetencegrpUtilisateurCriteria = $criteria;

		return $this->collJCompetencegrpUtilisateurs;
	}

	/**
	 * Clears out the collJAttestationItems collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJAttestationItems()
	 */
	public function clearJAttestationItems()
	{
		$this->collJAttestationItems = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJAttestationItems collection (array).
	 *
	 * By default this just sets the collJAttestationItems collection to an empty array (like clearcollJAttestationItems());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJAttestationItems()
	{
		$this->collJAttestationItems = array();
	}

	/**
	 * Gets an array of JAttestationItem objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp has previously been saved, it will retrieve
	 * related JAttestationItems from storage. If this CompetenceGrp is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JAttestationItem[]
	 * @throws     PropelException
	 */
	public function getJAttestationItems($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
			   $this->collJAttestationItems = array();
			} else {

				$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

				JAttestationItemPeer::addSelectColumns($criteria);
				$this->collJAttestationItems = JAttestationItemPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

				JAttestationItemPeer::addSelectColumns($criteria);
				if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
					$this->collJAttestationItems = JAttestationItemPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;
		return $this->collJAttestationItems;
	}

	/**
	 * Returns the number of related JAttestationItem objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JAttestationItem objects.
	 * @throws     PropelException
	 */
	public function countJAttestationItems(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

				$count = JAttestationItemPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

				if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
					$count = JAttestationItemPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJAttestationItems);
				}
			} else {
				$count = count($this->collJAttestationItems);
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JAttestationItem object to this object
	 * through the JAttestationItem foreign key attribute.
	 *
	 * @param      JAttestationItem $l JAttestationItem
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJAttestationItem(JAttestationItem $l)
	{
		if ($this->collJAttestationItems === null) {
			$this->initJAttestationItems();
		}
		if (!in_array($l, $this->collJAttestationItems, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJAttestationItems, $l);
			$l->setCompetenceGrp($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this CompetenceGrp is new, it will return
	 * an empty collection; or if this CompetenceGrp has previously
	 * been saved, it will retrieve related JAttestationItems from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in CompetenceGrp.
	 */
	public function getJAttestationItemsJoinAttestation($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetenceGrpPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
				$this->collJAttestationItems = array();
			} else {

				$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

				$this->collJAttestationItems = JAttestationItemPeer::doSelectJoinAttestation($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JAttestationItemPeer::CPTCEGRP_ID, $this->id);

			if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
				$this->collJAttestationItems = JAttestationItemPeer::doSelectJoinAttestation($criteria, $con, $join_behavior);
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;

		return $this->collJAttestationItems;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collCompetences) {
				foreach ((array) $this->collCompetences as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetencegrpUtilisateurs) {
				foreach ((array) $this->collJCompetencegrpUtilisateurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJAttestationItems) {
				foreach ((array) $this->collJAttestationItems as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collCompetences = null;
		$this->collJCompetencegrpUtilisateurs = null;
		$this->collJAttestationItems = null;
	}

} // BaseCompetenceGrp
