<?php

/**
 * Base class that represents a row from the 'grilles' table.
 *
 * Liste des grilles de competences
 *
 * @package    competencesrb.om
 */
abstract class BaseGrille extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        GrillePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nom field.
	 * @var        string
	 */
	protected $nom;

	/**
	 * The value for the type field.
	 * @var        string
	 */
	protected $type;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the matiere_id field.
	 * @var        int
	 */
	protected $matiere_id;

	/**
	 * The value for the created_on field.
	 * Note: this column has a database default value of: 0
	 * @var        int
	 */
	protected $created_on;

	/**
	 * The value for the utilisateur_id field.
	 * Note: this column has a database default value of: 0
	 * @var        int
	 */
	protected $utilisateur_id;

	/**
	 * @var        Matiere
	 */
	protected $aMatiere;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * @var        array JGrilleCompetence[] Collection to store aggregation of JGrilleCompetence objects.
	 */
	protected $collJGrilleCompetences;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGrilleCompetences.
	 */
	private $lastJGrilleCompetenceCriteria = null;

	/**
	 * @var        array JGrilleUtilisateur[] Collection to store aggregation of JGrilleUtilisateur objects.
	 */
	protected $collJGrilleUtilisateurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGrilleUtilisateurs.
	 */
	private $lastJGrilleUtilisateurCriteria = null;

	/**
	 * @var        array JGrilleGroupe[] Collection to store aggregation of JGrilleGroupe objects.
	 */
	protected $collJGrilleGroupes;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGrilleGroupes.
	 */
	private $lastJGrilleGroupeCriteria = null;

	/**
	 * @var        array Controle[] Collection to store aggregation of Controle objects.
	 */
	protected $collControles;

	/**
	 * @var        Criteria The criteria used to select the current contents of collControles.
	 */
	private $lastControleCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseGrille object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->created_on = 0;
		$this->utilisateur_id = 0;
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table grilles
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nom] column value.
	 * Nom de la grille
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Get the [type] column value.
	 * Type : peda perso
	 * @return     string
	 */
	public function getType()
	{
		return $this->type;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [matiere_id] column value.
	 * Matiere de la grille
	 * @return     int
	 */
	public function getMatiereId()
	{
		return $this->matiere_id;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation, timestamp UNIX
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Get the [utilisateur_id] column value.
	 * cle etrangere de l'utilisateur si type = perso
	 * @return     int
	 */
	public function getUtilisateurId()
	{
		return $this->utilisateur_id;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table grilles
	 * @param      int $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = GrillePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nom] column.
	 * Nom de la grille
	 * @param      string $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v) {
			$this->nom = $v;
			$this->modifiedColumns[] = GrillePeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Set the value of [type] column.
	 * Type : peda perso
	 * @param      string $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setType($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->type !== $v) {
			$this->type = $v;
			$this->modifiedColumns[] = GrillePeer::TYPE;
		}

		return $this;
	} // setType()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = GrillePeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [matiere_id] column.
	 * Matiere de la grille
	 * @param      int $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setMatiereId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->matiere_id !== $v) {
			$this->matiere_id = $v;
			$this->modifiedColumns[] = GrillePeer::MATIERE_ID;
		}

		if ($this->aMatiere !== null && $this->aMatiere->getId() !== $v) {
			$this->aMatiere = null;
		}

		return $this;
	} // setMatiereId()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation, timestamp UNIX
	 * @param      int $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v || $v === 0) {
			$this->created_on = $v;
			$this->modifiedColumns[] = GrillePeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Set the value of [utilisateur_id] column.
	 * cle etrangere de l'utilisateur si type = perso
	 * @param      int $v new value
	 * @return     Grille The current object (for fluent API support)
	 */
	public function setUtilisateurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->utilisateur_id !== $v || $v === 0) {
			$this->utilisateur_id = $v;
			$this->modifiedColumns[] = GrillePeer::UTILISATEUR_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setUtilisateurId()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(GrillePeer::CREATED_ON,GrillePeer::UTILISATEUR_ID))) {
				return false;
			}

			if ($this->created_on !== 0) {
				return false;
			}

			if ($this->utilisateur_id !== 0) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nom = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->type = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->rne = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->matiere_id = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->created_on = ($row[$startcol + 5] !== null) ? (int) $row[$startcol + 5] : null;
			$this->utilisateur_id = ($row[$startcol + 6] !== null) ? (int) $row[$startcol + 6] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 7; // 7 = GrillePeer::NUM_COLUMNS - GrillePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Grille object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aMatiere !== null && $this->matiere_id !== $this->aMatiere->getId()) {
			$this->aMatiere = null;
		}
		if ($this->aUtilisateur !== null && $this->utilisateur_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GrillePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = GrillePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aMatiere = null;
			$this->aUtilisateur = null;
			$this->collJGrilleCompetences = null;
			$this->lastJGrilleCompetenceCriteria = null;

			$this->collJGrilleUtilisateurs = null;
			$this->lastJGrilleUtilisateurCriteria = null;

			$this->collJGrilleGroupes = null;
			$this->lastJGrilleGroupeCriteria = null;

			$this->collControles = null;
			$this->lastControleCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GrillePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			GrillePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GrillePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			GrillePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aMatiere !== null) {
				if ($this->aMatiere->isModified() || $this->aMatiere->isNew()) {
					$affectedRows += $this->aMatiere->save($con);
				}
				$this->setMatiere($this->aMatiere);
			}

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = GrillePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = GrillePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += GrillePeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJGrilleCompetences !== null) {
				foreach ($this->collJGrilleCompetences as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJGrilleUtilisateurs !== null) {
				foreach ($this->collJGrilleUtilisateurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJGrilleGroupes !== null) {
				foreach ($this->collJGrilleGroupes as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collControles !== null) {
				foreach ($this->collControles as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aMatiere !== null) {
				if (!$this->aMatiere->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aMatiere->getValidationFailures());
				}
			}

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}


			if (($retval = GrillePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJGrilleCompetences !== null) {
					foreach ($this->collJGrilleCompetences as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJGrilleUtilisateurs !== null) {
					foreach ($this->collJGrilleUtilisateurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJGrilleGroupes !== null) {
					foreach ($this->collJGrilleGroupes as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collControles !== null) {
					foreach ($this->collControles as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = GrillePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNom();
				break;
			case 2:
				return $this->getType();
				break;
			case 3:
				return $this->getRne();
				break;
			case 4:
				return $this->getMatiereId();
				break;
			case 5:
				return $this->getCreatedOn();
				break;
			case 6:
				return $this->getUtilisateurId();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = GrillePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNom(),
			$keys[2] => $this->getType(),
			$keys[3] => $this->getRne(),
			$keys[4] => $this->getMatiereId(),
			$keys[5] => $this->getCreatedOn(),
			$keys[6] => $this->getUtilisateurId(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = GrillePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNom($value);
				break;
			case 2:
				$this->setType($value);
				break;
			case 3:
				$this->setRne($value);
				break;
			case 4:
				$this->setMatiereId($value);
				break;
			case 5:
				$this->setCreatedOn($value);
				break;
			case 6:
				$this->setUtilisateurId($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = GrillePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNom($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setType($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setRne($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setMatiereId($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setCreatedOn($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setUtilisateurId($arr[$keys[6]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(GrillePeer::DATABASE_NAME);

		if ($this->isColumnModified(GrillePeer::ID)) $criteria->add(GrillePeer::ID, $this->id);
		if ($this->isColumnModified(GrillePeer::NOM)) $criteria->add(GrillePeer::NOM, $this->nom);
		if ($this->isColumnModified(GrillePeer::TYPE)) $criteria->add(GrillePeer::TYPE, $this->type);
		if ($this->isColumnModified(GrillePeer::RNE)) $criteria->add(GrillePeer::RNE, $this->rne);
		if ($this->isColumnModified(GrillePeer::MATIERE_ID)) $criteria->add(GrillePeer::MATIERE_ID, $this->matiere_id);
		if ($this->isColumnModified(GrillePeer::CREATED_ON)) $criteria->add(GrillePeer::CREATED_ON, $this->created_on);
		if ($this->isColumnModified(GrillePeer::UTILISATEUR_ID)) $criteria->add(GrillePeer::UTILISATEUR_ID, $this->utilisateur_id);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(GrillePeer::DATABASE_NAME);

		$criteria->add(GrillePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Grille (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNom($this->nom);

		$copyObj->setType($this->type);

		$copyObj->setRne($this->rne);

		$copyObj->setMatiereId($this->matiere_id);

		$copyObj->setCreatedOn($this->created_on);

		$copyObj->setUtilisateurId($this->utilisateur_id);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJGrilleCompetences() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGrilleCompetence($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJGrilleUtilisateurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGrilleUtilisateur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJGrilleGroupes() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGrilleGroupe($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getControles() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addControle($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Grille Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     GrillePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new GrillePeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Matiere object.
	 *
	 * @param      Matiere $v
	 * @return     Grille The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setMatiere(Matiere $v = null)
	{
		if ($v === null) {
			$this->setMatiereId(NULL);
		} else {
			$this->setMatiereId($v->getId());
		}

		$this->aMatiere = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Matiere object, it will not be re-added.
		if ($v !== null) {
			$v->addGrille($this);
		}

		return $this;
	}


	/**
	 * Get the associated Matiere object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Matiere The associated Matiere object.
	 * @throws     PropelException
	 */
	public function getMatiere(PropelPDO $con = null)
	{
		if ($this->aMatiere === null && ($this->matiere_id !== null)) {
			$this->aMatiere = MatierePeer::retrieveByPK($this->matiere_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aMatiere->addGrilles($this);
			 */
		}
		return $this->aMatiere;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Grille The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setUtilisateurId(0);
		} else {
			$this->setUtilisateurId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addGrille($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->utilisateur_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->utilisateur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addGrilles($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Clears out the collJGrilleCompetences collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGrilleCompetences()
	 */
	public function clearJGrilleCompetences()
	{
		$this->collJGrilleCompetences = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGrilleCompetences collection (array).
	 *
	 * By default this just sets the collJGrilleCompetences collection to an empty array (like clearcollJGrilleCompetences());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGrilleCompetences()
	{
		$this->collJGrilleCompetences = array();
	}

	/**
	 * Gets an array of JGrilleCompetence objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Grille has previously been saved, it will retrieve
	 * related JGrilleCompetences from storage. If this Grille is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGrilleCompetence[]
	 * @throws     PropelException
	 */
	public function getJGrilleCompetences($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
			   $this->collJGrilleCompetences = array();
			} else {

				$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

				JGrilleCompetencePeer::addSelectColumns($criteria);
				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

				JGrilleCompetencePeer::addSelectColumns($criteria);
				if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
					$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;
		return $this->collJGrilleCompetences;
	}

	/**
	 * Returns the number of related JGrilleCompetence objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGrilleCompetence objects.
	 * @throws     PropelException
	 */
	public function countJGrilleCompetences(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

				$count = JGrilleCompetencePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

				if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
					$count = JGrilleCompetencePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGrilleCompetences);
				}
			} else {
				$count = count($this->collJGrilleCompetences);
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGrilleCompetence object to this object
	 * through the JGrilleCompetence foreign key attribute.
	 *
	 * @param      JGrilleCompetence $l JGrilleCompetence
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGrilleCompetence(JGrilleCompetence $l)
	{
		if ($this->collJGrilleCompetences === null) {
			$this->initJGrilleCompetences();
		}
		if (!in_array($l, $this->collJGrilleCompetences, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGrilleCompetences, $l);
			$l->setGrille($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Grille is new, it will return
	 * an empty collection; or if this Grille has previously
	 * been saved, it will retrieve related JGrilleCompetences from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Grille.
	 */
	public function getJGrilleCompetencesJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
				$this->collJGrilleCompetences = array();
			} else {

				$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGrilleCompetencePeer::GRILLE_ID, $this->id);

			if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;

		return $this->collJGrilleCompetences;
	}

	/**
	 * Clears out the collJGrilleUtilisateurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGrilleUtilisateurs()
	 */
	public function clearJGrilleUtilisateurs()
	{
		$this->collJGrilleUtilisateurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGrilleUtilisateurs collection (array).
	 *
	 * By default this just sets the collJGrilleUtilisateurs collection to an empty array (like clearcollJGrilleUtilisateurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGrilleUtilisateurs()
	{
		$this->collJGrilleUtilisateurs = array();
	}

	/**
	 * Gets an array of JGrilleUtilisateur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Grille has previously been saved, it will retrieve
	 * related JGrilleUtilisateurs from storage. If this Grille is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGrilleUtilisateur[]
	 * @throws     PropelException
	 */
	public function getJGrilleUtilisateurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleUtilisateurs === null) {
			if ($this->isNew()) {
			   $this->collJGrilleUtilisateurs = array();
			} else {

				$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

				JGrilleUtilisateurPeer::addSelectColumns($criteria);
				$this->collJGrilleUtilisateurs = JGrilleUtilisateurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

				JGrilleUtilisateurPeer::addSelectColumns($criteria);
				if (!isset($this->lastJGrilleUtilisateurCriteria) || !$this->lastJGrilleUtilisateurCriteria->equals($criteria)) {
					$this->collJGrilleUtilisateurs = JGrilleUtilisateurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGrilleUtilisateurCriteria = $criteria;
		return $this->collJGrilleUtilisateurs;
	}

	/**
	 * Returns the number of related JGrilleUtilisateur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGrilleUtilisateur objects.
	 * @throws     PropelException
	 */
	public function countJGrilleUtilisateurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGrilleUtilisateurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

				$count = JGrilleUtilisateurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

				if (!isset($this->lastJGrilleUtilisateurCriteria) || !$this->lastJGrilleUtilisateurCriteria->equals($criteria)) {
					$count = JGrilleUtilisateurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGrilleUtilisateurs);
				}
			} else {
				$count = count($this->collJGrilleUtilisateurs);
			}
		}
		$this->lastJGrilleUtilisateurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGrilleUtilisateur object to this object
	 * through the JGrilleUtilisateur foreign key attribute.
	 *
	 * @param      JGrilleUtilisateur $l JGrilleUtilisateur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGrilleUtilisateur(JGrilleUtilisateur $l)
	{
		if ($this->collJGrilleUtilisateurs === null) {
			$this->initJGrilleUtilisateurs();
		}
		if (!in_array($l, $this->collJGrilleUtilisateurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGrilleUtilisateurs, $l);
			$l->setGrille($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Grille is new, it will return
	 * an empty collection; or if this Grille has previously
	 * been saved, it will retrieve related JGrilleUtilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Grille.
	 */
	public function getJGrilleUtilisateursJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collJGrilleUtilisateurs = array();
			} else {

				$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

				$this->collJGrilleUtilisateurs = JGrilleUtilisateurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGrilleUtilisateurPeer::GRILLE_ID, $this->id);

			if (!isset($this->lastJGrilleUtilisateurCriteria) || !$this->lastJGrilleUtilisateurCriteria->equals($criteria)) {
				$this->collJGrilleUtilisateurs = JGrilleUtilisateurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGrilleUtilisateurCriteria = $criteria;

		return $this->collJGrilleUtilisateurs;
	}

	/**
	 * Clears out the collJGrilleGroupes collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGrilleGroupes()
	 */
	public function clearJGrilleGroupes()
	{
		$this->collJGrilleGroupes = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGrilleGroupes collection (array).
	 *
	 * By default this just sets the collJGrilleGroupes collection to an empty array (like clearcollJGrilleGroupes());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGrilleGroupes()
	{
		$this->collJGrilleGroupes = array();
	}

	/**
	 * Gets an array of JGrilleGroupe objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Grille has previously been saved, it will retrieve
	 * related JGrilleGroupes from storage. If this Grille is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGrilleGroupe[]
	 * @throws     PropelException
	 */
	public function getJGrilleGroupes($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
			   $this->collJGrilleGroupes = array();
			} else {

				$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

				JGrilleGroupePeer::addSelectColumns($criteria);
				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

				JGrilleGroupePeer::addSelectColumns($criteria);
				if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
					$this->collJGrilleGroupes = JGrilleGroupePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;
		return $this->collJGrilleGroupes;
	}

	/**
	 * Returns the number of related JGrilleGroupe objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGrilleGroupe objects.
	 * @throws     PropelException
	 */
	public function countJGrilleGroupes(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

				$count = JGrilleGroupePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

				if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
					$count = JGrilleGroupePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGrilleGroupes);
				}
			} else {
				$count = count($this->collJGrilleGroupes);
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGrilleGroupe object to this object
	 * through the JGrilleGroupe foreign key attribute.
	 *
	 * @param      JGrilleGroupe $l JGrilleGroupe
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGrilleGroupe(JGrilleGroupe $l)
	{
		if ($this->collJGrilleGroupes === null) {
			$this->initJGrilleGroupes();
		}
		if (!in_array($l, $this->collJGrilleGroupes, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGrilleGroupes, $l);
			$l->setGrille($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Grille is new, it will return
	 * an empty collection; or if this Grille has previously
	 * been saved, it will retrieve related JGrilleGroupes from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Grille.
	 */
	public function getJGrilleGroupesJoinGroupe($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
				$this->collJGrilleGroupes = array();
			} else {

				$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelectJoinGroupe($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGrilleGroupePeer::GRILLE_ID, $this->id);

			if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelectJoinGroupe($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;

		return $this->collJGrilleGroupes;
	}

	/**
	 * Clears out the collControles collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addControles()
	 */
	public function clearControles()
	{
		$this->collControles = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collControles collection (array).
	 *
	 * By default this just sets the collControles collection to an empty array (like clearcollControles());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initControles()
	{
		$this->collControles = array();
	}

	/**
	 * Gets an array of Controle objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Grille has previously been saved, it will retrieve
	 * related Controles from storage. If this Grille is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Controle[]
	 * @throws     PropelException
	 */
	public function getControles($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collControles === null) {
			if ($this->isNew()) {
			   $this->collControles = array();
			} else {

				$criteria->add(ControlePeer::GRILLE_ID, $this->id);

				ControlePeer::addSelectColumns($criteria);
				$this->collControles = ControlePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(ControlePeer::GRILLE_ID, $this->id);

				ControlePeer::addSelectColumns($criteria);
				if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
					$this->collControles = ControlePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastControleCriteria = $criteria;
		return $this->collControles;
	}

	/**
	 * Returns the number of related Controle objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Controle objects.
	 * @throws     PropelException
	 */
	public function countControles(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collControles === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(ControlePeer::GRILLE_ID, $this->id);

				$count = ControlePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(ControlePeer::GRILLE_ID, $this->id);

				if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
					$count = ControlePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collControles);
				}
			} else {
				$count = count($this->collControles);
			}
		}
		$this->lastControleCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Controle object to this object
	 * through the Controle foreign key attribute.
	 *
	 * @param      Controle $l Controle
	 * @return     void
	 * @throws     PropelException
	 */
	public function addControle(Controle $l)
	{
		if ($this->collControles === null) {
			$this->initControles();
		}
		if (!in_array($l, $this->collControles, true)) { // only add it if the **same** object is not already associated
			array_push($this->collControles, $l);
			$l->setGrille($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Grille is new, it will return
	 * an empty collection; or if this Grille has previously
	 * been saved, it will retrieve related Controles from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Grille.
	 */
	public function getControlesJoinGroupe($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GrillePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collControles === null) {
			if ($this->isNew()) {
				$this->collControles = array();
			} else {

				$criteria->add(ControlePeer::GRILLE_ID, $this->id);

				$this->collControles = ControlePeer::doSelectJoinGroupe($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(ControlePeer::GRILLE_ID, $this->id);

			if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
				$this->collControles = ControlePeer::doSelectJoinGroupe($criteria, $con, $join_behavior);
			}
		}
		$this->lastControleCriteria = $criteria;

		return $this->collControles;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJGrilleCompetences) {
				foreach ((array) $this->collJGrilleCompetences as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJGrilleUtilisateurs) {
				foreach ((array) $this->collJGrilleUtilisateurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJGrilleGroupes) {
				foreach ((array) $this->collJGrilleGroupes as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collControles) {
				foreach ((array) $this->collControles as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJGrilleCompetences = null;
		$this->collJGrilleUtilisateurs = null;
		$this->collJGrilleGroupes = null;
		$this->collControles = null;
			$this->aMatiere = null;
			$this->aUtilisateur = null;
	}

} // BaseGrille
