<?php

/**
 * Base class that represents a row from the 'groupes' table.
 *
 * Liste des groupes
 *
 * @package    competencesrb.om
 */
abstract class BaseGroupe extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        GroupePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nomcourt field.
	 * @var        string
	 */
	protected $nomcourt;

	/**
	 * The value for the nomlong field.
	 * @var        string
	 */
	protected $nomlong;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * @var        array JGrilleGroupe[] Collection to store aggregation of JGrilleGroupe objects.
	 */
	protected $collJGrilleGroupes;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGrilleGroupes.
	 */
	private $lastJGrilleGroupeCriteria = null;

	/**
	 * @var        array Controle[] Collection to store aggregation of Controle objects.
	 */
	protected $collControles;

	/**
	 * @var        Criteria The criteria used to select the current contents of collControles.
	 */
	private $lastControleCriteria = null;

	/**
	 * @var        array JGroupePossesseur[] Collection to store aggregation of JGroupePossesseur objects.
	 */
	protected $collJGroupePossesseurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGroupePossesseurs.
	 */
	private $lastJGroupePossesseurCriteria = null;

	/**
	 * @var        array JGroupeEleve[] Collection to store aggregation of JGroupeEleve objects.
	 */
	protected $collJGroupeEleves;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGroupeEleves.
	 */
	private $lastJGroupeEleveCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseGroupe object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table groupes
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nomcourt] column value.
	 * Nom court du groupe
	 * @return     string
	 */
	public function getNomcourt()
	{
		return $this->nomcourt;
	}

	/**
	 * Get the [nomlong] column value.
	 * Nom long du groupe
	 * @return     string
	 */
	public function getNomlong()
	{
		return $this->nomlong;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table groupes
	 * @param      int $v new value
	 * @return     Groupe The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = GroupePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nomcourt] column.
	 * Nom court du groupe
	 * @param      string $v new value
	 * @return     Groupe The current object (for fluent API support)
	 */
	public function setNomcourt($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomcourt !== $v) {
			$this->nomcourt = $v;
			$this->modifiedColumns[] = GroupePeer::NOMCOURT;
		}

		return $this;
	} // setNomcourt()

	/**
	 * Set the value of [nomlong] column.
	 * Nom long du groupe
	 * @param      string $v new value
	 * @return     Groupe The current object (for fluent API support)
	 */
	public function setNomlong($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomlong !== $v) {
			$this->nomlong = $v;
			$this->modifiedColumns[] = GroupePeer::NOMLONG;
		}

		return $this;
	} // setNomlong()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     Groupe The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = GroupePeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nomcourt = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->nomlong = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->rne = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 4; // 4 = GroupePeer::NUM_COLUMNS - GroupePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Groupe object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GroupePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = GroupePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->collJGrilleGroupes = null;
			$this->lastJGrilleGroupeCriteria = null;

			$this->collControles = null;
			$this->lastControleCriteria = null;

			$this->collJGroupePossesseurs = null;
			$this->lastJGroupePossesseurCriteria = null;

			$this->collJGroupeEleves = null;
			$this->lastJGroupeEleveCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GroupePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			GroupePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(GroupePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			GroupePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			if ($this->isNew() ) {
				$this->modifiedColumns[] = GroupePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = GroupePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += GroupePeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJGrilleGroupes !== null) {
				foreach ($this->collJGrilleGroupes as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collControles !== null) {
				foreach ($this->collControles as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJGroupePossesseurs !== null) {
				foreach ($this->collJGroupePossesseurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJGroupeEleves !== null) {
				foreach ($this->collJGroupeEleves as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			if (($retval = GroupePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJGrilleGroupes !== null) {
					foreach ($this->collJGrilleGroupes as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collControles !== null) {
					foreach ($this->collControles as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJGroupePossesseurs !== null) {
					foreach ($this->collJGroupePossesseurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJGroupeEleves !== null) {
					foreach ($this->collJGroupeEleves as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = GroupePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNomcourt();
				break;
			case 2:
				return $this->getNomlong();
				break;
			case 3:
				return $this->getRne();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = GroupePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNomcourt(),
			$keys[2] => $this->getNomlong(),
			$keys[3] => $this->getRne(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = GroupePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNomcourt($value);
				break;
			case 2:
				$this->setNomlong($value);
				break;
			case 3:
				$this->setRne($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = GroupePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNomcourt($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setNomlong($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setRne($arr[$keys[3]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(GroupePeer::DATABASE_NAME);

		if ($this->isColumnModified(GroupePeer::ID)) $criteria->add(GroupePeer::ID, $this->id);
		if ($this->isColumnModified(GroupePeer::NOMCOURT)) $criteria->add(GroupePeer::NOMCOURT, $this->nomcourt);
		if ($this->isColumnModified(GroupePeer::NOMLONG)) $criteria->add(GroupePeer::NOMLONG, $this->nomlong);
		if ($this->isColumnModified(GroupePeer::RNE)) $criteria->add(GroupePeer::RNE, $this->rne);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(GroupePeer::DATABASE_NAME);

		$criteria->add(GroupePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Groupe (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNomcourt($this->nomcourt);

		$copyObj->setNomlong($this->nomlong);

		$copyObj->setRne($this->rne);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJGrilleGroupes() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGrilleGroupe($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getControles() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addControle($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJGroupePossesseurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGroupePossesseur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJGroupeEleves() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGroupeEleve($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Groupe Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     GroupePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new GroupePeer();
		}
		return self::$peer;
	}

	/**
	 * Clears out the collJGrilleGroupes collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGrilleGroupes()
	 */
	public function clearJGrilleGroupes()
	{
		$this->collJGrilleGroupes = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGrilleGroupes collection (array).
	 *
	 * By default this just sets the collJGrilleGroupes collection to an empty array (like clearcollJGrilleGroupes());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGrilleGroupes()
	{
		$this->collJGrilleGroupes = array();
	}

	/**
	 * Gets an array of JGrilleGroupe objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Groupe has previously been saved, it will retrieve
	 * related JGrilleGroupes from storage. If this Groupe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGrilleGroupe[]
	 * @throws     PropelException
	 */
	public function getJGrilleGroupes($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
			   $this->collJGrilleGroupes = array();
			} else {

				$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

				JGrilleGroupePeer::addSelectColumns($criteria);
				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

				JGrilleGroupePeer::addSelectColumns($criteria);
				if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
					$this->collJGrilleGroupes = JGrilleGroupePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;
		return $this->collJGrilleGroupes;
	}

	/**
	 * Returns the number of related JGrilleGroupe objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGrilleGroupe objects.
	 * @throws     PropelException
	 */
	public function countJGrilleGroupes(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

				$count = JGrilleGroupePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

				if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
					$count = JGrilleGroupePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGrilleGroupes);
				}
			} else {
				$count = count($this->collJGrilleGroupes);
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGrilleGroupe object to this object
	 * through the JGrilleGroupe foreign key attribute.
	 *
	 * @param      JGrilleGroupe $l JGrilleGroupe
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGrilleGroupe(JGrilleGroupe $l)
	{
		if ($this->collJGrilleGroupes === null) {
			$this->initJGrilleGroupes();
		}
		if (!in_array($l, $this->collJGrilleGroupes, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGrilleGroupes, $l);
			$l->setGroupe($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Groupe is new, it will return
	 * an empty collection; or if this Groupe has previously
	 * been saved, it will retrieve related JGrilleGroupes from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Groupe.
	 */
	public function getJGrilleGroupesJoinGrille($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleGroupes === null) {
			if ($this->isNew()) {
				$this->collJGrilleGroupes = array();
			} else {

				$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGrilleGroupePeer::GROUPE_ID, $this->id);

			if (!isset($this->lastJGrilleGroupeCriteria) || !$this->lastJGrilleGroupeCriteria->equals($criteria)) {
				$this->collJGrilleGroupes = JGrilleGroupePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGrilleGroupeCriteria = $criteria;

		return $this->collJGrilleGroupes;
	}

	/**
	 * Clears out the collControles collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addControles()
	 */
	public function clearControles()
	{
		$this->collControles = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collControles collection (array).
	 *
	 * By default this just sets the collControles collection to an empty array (like clearcollControles());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initControles()
	{
		$this->collControles = array();
	}

	/**
	 * Gets an array of Controle objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Groupe has previously been saved, it will retrieve
	 * related Controles from storage. If this Groupe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Controle[]
	 * @throws     PropelException
	 */
	public function getControles($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collControles === null) {
			if ($this->isNew()) {
			   $this->collControles = array();
			} else {

				$criteria->add(ControlePeer::GROUPE_ID, $this->id);

				ControlePeer::addSelectColumns($criteria);
				$this->collControles = ControlePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(ControlePeer::GROUPE_ID, $this->id);

				ControlePeer::addSelectColumns($criteria);
				if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
					$this->collControles = ControlePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastControleCriteria = $criteria;
		return $this->collControles;
	}

	/**
	 * Returns the number of related Controle objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Controle objects.
	 * @throws     PropelException
	 */
	public function countControles(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collControles === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(ControlePeer::GROUPE_ID, $this->id);

				$count = ControlePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(ControlePeer::GROUPE_ID, $this->id);

				if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
					$count = ControlePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collControles);
				}
			} else {
				$count = count($this->collControles);
			}
		}
		$this->lastControleCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Controle object to this object
	 * through the Controle foreign key attribute.
	 *
	 * @param      Controle $l Controle
	 * @return     void
	 * @throws     PropelException
	 */
	public function addControle(Controle $l)
	{
		if ($this->collControles === null) {
			$this->initControles();
		}
		if (!in_array($l, $this->collControles, true)) { // only add it if the **same** object is not already associated
			array_push($this->collControles, $l);
			$l->setGroupe($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Groupe is new, it will return
	 * an empty collection; or if this Groupe has previously
	 * been saved, it will retrieve related Controles from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Groupe.
	 */
	public function getControlesJoinGrille($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collControles === null) {
			if ($this->isNew()) {
				$this->collControles = array();
			} else {

				$criteria->add(ControlePeer::GROUPE_ID, $this->id);

				$this->collControles = ControlePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(ControlePeer::GROUPE_ID, $this->id);

			if (!isset($this->lastControleCriteria) || !$this->lastControleCriteria->equals($criteria)) {
				$this->collControles = ControlePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		}
		$this->lastControleCriteria = $criteria;

		return $this->collControles;
	}

	/**
	 * Clears out the collJGroupePossesseurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGroupePossesseurs()
	 */
	public function clearJGroupePossesseurs()
	{
		$this->collJGroupePossesseurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGroupePossesseurs collection (array).
	 *
	 * By default this just sets the collJGroupePossesseurs collection to an empty array (like clearcollJGroupePossesseurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGroupePossesseurs()
	{
		$this->collJGroupePossesseurs = array();
	}

	/**
	 * Gets an array of JGroupePossesseur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Groupe has previously been saved, it will retrieve
	 * related JGroupePossesseurs from storage. If this Groupe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGroupePossesseur[]
	 * @throws     PropelException
	 */
	public function getJGroupePossesseurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGroupePossesseurs === null) {
			if ($this->isNew()) {
			   $this->collJGroupePossesseurs = array();
			} else {

				$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

				JGroupePossesseurPeer::addSelectColumns($criteria);
				$this->collJGroupePossesseurs = JGroupePossesseurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

				JGroupePossesseurPeer::addSelectColumns($criteria);
				if (!isset($this->lastJGroupePossesseurCriteria) || !$this->lastJGroupePossesseurCriteria->equals($criteria)) {
					$this->collJGroupePossesseurs = JGroupePossesseurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGroupePossesseurCriteria = $criteria;
		return $this->collJGroupePossesseurs;
	}

	/**
	 * Returns the number of related JGroupePossesseur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGroupePossesseur objects.
	 * @throws     PropelException
	 */
	public function countJGroupePossesseurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGroupePossesseurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

				$count = JGroupePossesseurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

				if (!isset($this->lastJGroupePossesseurCriteria) || !$this->lastJGroupePossesseurCriteria->equals($criteria)) {
					$count = JGroupePossesseurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGroupePossesseurs);
				}
			} else {
				$count = count($this->collJGroupePossesseurs);
			}
		}
		$this->lastJGroupePossesseurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGroupePossesseur object to this object
	 * through the JGroupePossesseur foreign key attribute.
	 *
	 * @param      JGroupePossesseur $l JGroupePossesseur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGroupePossesseur(JGroupePossesseur $l)
	{
		if ($this->collJGroupePossesseurs === null) {
			$this->initJGroupePossesseurs();
		}
		if (!in_array($l, $this->collJGroupePossesseurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGroupePossesseurs, $l);
			$l->setGroupe($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Groupe is new, it will return
	 * an empty collection; or if this Groupe has previously
	 * been saved, it will retrieve related JGroupePossesseurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Groupe.
	 */
	public function getJGroupePossesseursJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGroupePossesseurs === null) {
			if ($this->isNew()) {
				$this->collJGroupePossesseurs = array();
			} else {

				$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

				$this->collJGroupePossesseurs = JGroupePossesseurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGroupePossesseurPeer::GROUPE_ID, $this->id);

			if (!isset($this->lastJGroupePossesseurCriteria) || !$this->lastJGroupePossesseurCriteria->equals($criteria)) {
				$this->collJGroupePossesseurs = JGroupePossesseurPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGroupePossesseurCriteria = $criteria;

		return $this->collJGroupePossesseurs;
	}

	/**
	 * Clears out the collJGroupeEleves collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGroupeEleves()
	 */
	public function clearJGroupeEleves()
	{
		$this->collJGroupeEleves = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGroupeEleves collection (array).
	 *
	 * By default this just sets the collJGroupeEleves collection to an empty array (like clearcollJGroupeEleves());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGroupeEleves()
	{
		$this->collJGroupeEleves = array();
	}

	/**
	 * Gets an array of JGroupeEleve objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Groupe has previously been saved, it will retrieve
	 * related JGroupeEleves from storage. If this Groupe is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGroupeEleve[]
	 * @throws     PropelException
	 */
	public function getJGroupeEleves($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGroupeEleves === null) {
			if ($this->isNew()) {
			   $this->collJGroupeEleves = array();
			} else {

				$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

				JGroupeElevePeer::addSelectColumns($criteria);
				$this->collJGroupeEleves = JGroupeElevePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

				JGroupeElevePeer::addSelectColumns($criteria);
				if (!isset($this->lastJGroupeEleveCriteria) || !$this->lastJGroupeEleveCriteria->equals($criteria)) {
					$this->collJGroupeEleves = JGroupeElevePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGroupeEleveCriteria = $criteria;
		return $this->collJGroupeEleves;
	}

	/**
	 * Returns the number of related JGroupeEleve objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGroupeEleve objects.
	 * @throws     PropelException
	 */
	public function countJGroupeEleves(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGroupeEleves === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

				$count = JGroupeElevePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

				if (!isset($this->lastJGroupeEleveCriteria) || !$this->lastJGroupeEleveCriteria->equals($criteria)) {
					$count = JGroupeElevePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGroupeEleves);
				}
			} else {
				$count = count($this->collJGroupeEleves);
			}
		}
		$this->lastJGroupeEleveCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGroupeEleve object to this object
	 * through the JGroupeEleve foreign key attribute.
	 *
	 * @param      JGroupeEleve $l JGroupeEleve
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGroupeEleve(JGroupeEleve $l)
	{
		if ($this->collJGroupeEleves === null) {
			$this->initJGroupeEleves();
		}
		if (!in_array($l, $this->collJGroupeEleves, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGroupeEleves, $l);
			$l->setGroupe($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Groupe is new, it will return
	 * an empty collection; or if this Groupe has previously
	 * been saved, it will retrieve related JGroupeEleves from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Groupe.
	 */
	public function getJGroupeElevesJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(GroupePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGroupeEleves === null) {
			if ($this->isNew()) {
				$this->collJGroupeEleves = array();
			} else {

				$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

				$this->collJGroupeEleves = JGroupeElevePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGroupeElevePeer::GROUPE_ID, $this->id);

			if (!isset($this->lastJGroupeEleveCriteria) || !$this->lastJGroupeEleveCriteria->equals($criteria)) {
				$this->collJGroupeEleves = JGroupeElevePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGroupeEleveCriteria = $criteria;

		return $this->collJGroupeEleves;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJGrilleGroupes) {
				foreach ((array) $this->collJGrilleGroupes as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collControles) {
				foreach ((array) $this->collControles as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJGroupePossesseurs) {
				foreach ((array) $this->collJGroupePossesseurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJGroupeEleves) {
				foreach ((array) $this->collJGroupeEleves as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJGrilleGroupes = null;
		$this->collControles = null;
		$this->collJGroupePossesseurs = null;
		$this->collJGroupeEleves = null;
	}

} // BaseGroupe
