<?php

/**
 * Base class that represents a row from the 'competence_ressources' table.
 *
 * Quelle ressource pour quelle competence ?
 *
 * @package    competencesrb.om
 */
abstract class BaseJCompetenceRessources extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JCompetenceRessourcesPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the competence_id field.
	 * @var        int
	 */
	protected $competence_id;

	/**
	 * The value for the ressource_id field.
	 * @var        int
	 */
	protected $ressource_id;

	/**
	 * The value for the validation field.
	 * @var        string
	 */
	protected $validation;

	/**
	 * The value for the matiere_id field.
	 * @var        int
	 */
	protected $matiere_id;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * @var        Competence
	 */
	protected $aCompetence;

	/**
	 * @var        Ressource
	 */
	protected $aRessource;

	/**
	 * @var        Matiere
	 */
	protected $aMatiere;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJCompetenceRessources object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table competence_ressources
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [competence_id] column value.
	 * cle etrangere de la table competences
	 * @return     int
	 */
	public function getCompetenceId()
	{
		return $this->competence_id;
	}

	/**
	 * Get the [ressource_id] column value.
	 * cle etrangere de la ressource
	 * @return     int
	 */
	public function getRessourceId()
	{
		return $this->ressource_id;
	}

	/**
	 * Get the [validation] column value.
	 * Pour quel niveau de validation ? on stocke la lettre
	 * @return     string
	 */
	public function getValidation()
	{
		return $this->validation;
	}

	/**
	 * Get the [matiere_id] column value.
	 * cle etrangere de la matiere
	 * @return     int
	 */
	public function getMatiereId()
	{
		return $this->matiere_id;
	}

	/**
	 * Get the [rne] column value.
	 * Rne de l'etablissement de cette association competence-ressource
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table competence_ressources
	 * @param      int $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [competence_id] column.
	 * cle etrangere de la table competences
	 * @param      int $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setCompetenceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->competence_id !== $v) {
			$this->competence_id = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::COMPETENCE_ID;
		}

		if ($this->aCompetence !== null && $this->aCompetence->getId() !== $v) {
			$this->aCompetence = null;
		}

		return $this;
	} // setCompetenceId()

	/**
	 * Set the value of [ressource_id] column.
	 * cle etrangere de la ressource
	 * @param      int $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setRessourceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->ressource_id !== $v) {
			$this->ressource_id = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::RESSOURCE_ID;
		}

		if ($this->aRessource !== null && $this->aRessource->getId() !== $v) {
			$this->aRessource = null;
		}

		return $this;
	} // setRessourceId()

	/**
	 * Set the value of [validation] column.
	 * Pour quel niveau de validation ? on stocke la lettre
	 * @param      string $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setValidation($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->validation !== $v) {
			$this->validation = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::VALIDATION;
		}

		return $this;
	} // setValidation()

	/**
	 * Set the value of [matiere_id] column.
	 * cle etrangere de la matiere
	 * @param      int $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setMatiereId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->matiere_id !== $v) {
			$this->matiere_id = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::MATIERE_ID;
		}

		if ($this->aMatiere !== null && $this->aMatiere->getId() !== $v) {
			$this->aMatiere = null;
		}

		return $this;
	} // setMatiereId()

	/**
	 * Set the value of [rne] column.
	 * Rne de l'etablissement de cette association competence-ressource
	 * @param      string $v new value
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = JCompetenceRessourcesPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->competence_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->ressource_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->validation = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->matiere_id = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->rne = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 6; // 6 = JCompetenceRessourcesPeer::NUM_COLUMNS - JCompetenceRessourcesPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JCompetenceRessources object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aCompetence !== null && $this->competence_id !== $this->aCompetence->getId()) {
			$this->aCompetence = null;
		}
		if ($this->aRessource !== null && $this->ressource_id !== $this->aRessource->getId()) {
			$this->aRessource = null;
		}
		if ($this->aMatiere !== null && $this->matiere_id !== $this->aMatiere->getId()) {
			$this->aMatiere = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JCompetenceRessourcesPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JCompetenceRessourcesPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aCompetence = null;
			$this->aRessource = null;
			$this->aMatiere = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JCompetenceRessourcesPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JCompetenceRessourcesPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JCompetenceRessourcesPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JCompetenceRessourcesPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aCompetence !== null) {
				if ($this->aCompetence->isModified() || $this->aCompetence->isNew()) {
					$affectedRows += $this->aCompetence->save($con);
				}
				$this->setCompetence($this->aCompetence);
			}

			if ($this->aRessource !== null) {
				if ($this->aRessource->isModified() || $this->aRessource->isNew()) {
					$affectedRows += $this->aRessource->save($con);
				}
				$this->setRessource($this->aRessource);
			}

			if ($this->aMatiere !== null) {
				if ($this->aMatiere->isModified() || $this->aMatiere->isNew()) {
					$affectedRows += $this->aMatiere->save($con);
				}
				$this->setMatiere($this->aMatiere);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = JCompetenceRessourcesPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JCompetenceRessourcesPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += JCompetenceRessourcesPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aCompetence !== null) {
				if (!$this->aCompetence->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCompetence->getValidationFailures());
				}
			}

			if ($this->aRessource !== null) {
				if (!$this->aRessource->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aRessource->getValidationFailures());
				}
			}

			if ($this->aMatiere !== null) {
				if (!$this->aMatiere->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aMatiere->getValidationFailures());
				}
			}


			if (($retval = JCompetenceRessourcesPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JCompetenceRessourcesPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getCompetenceId();
				break;
			case 2:
				return $this->getRessourceId();
				break;
			case 3:
				return $this->getValidation();
				break;
			case 4:
				return $this->getMatiereId();
				break;
			case 5:
				return $this->getRne();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JCompetenceRessourcesPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getCompetenceId(),
			$keys[2] => $this->getRessourceId(),
			$keys[3] => $this->getValidation(),
			$keys[4] => $this->getMatiereId(),
			$keys[5] => $this->getRne(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JCompetenceRessourcesPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setCompetenceId($value);
				break;
			case 2:
				$this->setRessourceId($value);
				break;
			case 3:
				$this->setValidation($value);
				break;
			case 4:
				$this->setMatiereId($value);
				break;
			case 5:
				$this->setRne($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JCompetenceRessourcesPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setCompetenceId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setRessourceId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setValidation($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setMatiereId($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setRne($arr[$keys[5]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JCompetenceRessourcesPeer::DATABASE_NAME);

		if ($this->isColumnModified(JCompetenceRessourcesPeer::ID)) $criteria->add(JCompetenceRessourcesPeer::ID, $this->id);
		if ($this->isColumnModified(JCompetenceRessourcesPeer::COMPETENCE_ID)) $criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->competence_id);
		if ($this->isColumnModified(JCompetenceRessourcesPeer::RESSOURCE_ID)) $criteria->add(JCompetenceRessourcesPeer::RESSOURCE_ID, $this->ressource_id);
		if ($this->isColumnModified(JCompetenceRessourcesPeer::VALIDATION)) $criteria->add(JCompetenceRessourcesPeer::VALIDATION, $this->validation);
		if ($this->isColumnModified(JCompetenceRessourcesPeer::MATIERE_ID)) $criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->matiere_id);
		if ($this->isColumnModified(JCompetenceRessourcesPeer::RNE)) $criteria->add(JCompetenceRessourcesPeer::RNE, $this->rne);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JCompetenceRessourcesPeer::DATABASE_NAME);

		$criteria->add(JCompetenceRessourcesPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JCompetenceRessources (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setCompetenceId($this->competence_id);

		$copyObj->setRessourceId($this->ressource_id);

		$copyObj->setValidation($this->validation);

		$copyObj->setMatiereId($this->matiere_id);

		$copyObj->setRne($this->rne);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JCompetenceRessources Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JCompetenceRessourcesPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JCompetenceRessourcesPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Competence object.
	 *
	 * @param      Competence $v
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setCompetence(Competence $v = null)
	{
		if ($v === null) {
			$this->setCompetenceId(NULL);
		} else {
			$this->setCompetenceId($v->getId());
		}

		$this->aCompetence = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Competence object, it will not be re-added.
		if ($v !== null) {
			$v->addJCompetenceRessources($this);
		}

		return $this;
	}


	/**
	 * Get the associated Competence object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Competence The associated Competence object.
	 * @throws     PropelException
	 */
	public function getCompetence(PropelPDO $con = null)
	{
		if ($this->aCompetence === null && ($this->competence_id !== null)) {
			$this->aCompetence = CompetencePeer::retrieveByPK($this->competence_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aCompetence->addJCompetenceRessourcess($this);
			 */
		}
		return $this->aCompetence;
	}

	/**
	 * Declares an association between this object and a Ressource object.
	 *
	 * @param      Ressource $v
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setRessource(Ressource $v = null)
	{
		if ($v === null) {
			$this->setRessourceId(NULL);
		} else {
			$this->setRessourceId($v->getId());
		}

		$this->aRessource = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Ressource object, it will not be re-added.
		if ($v !== null) {
			$v->addJCompetenceRessources($this);
		}

		return $this;
	}


	/**
	 * Get the associated Ressource object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Ressource The associated Ressource object.
	 * @throws     PropelException
	 */
	public function getRessource(PropelPDO $con = null)
	{
		if ($this->aRessource === null && ($this->ressource_id !== null)) {
			$this->aRessource = RessourcePeer::retrieveByPK($this->ressource_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aRessource->addJCompetenceRessourcess($this);
			 */
		}
		return $this->aRessource;
	}

	/**
	 * Declares an association between this object and a Matiere object.
	 *
	 * @param      Matiere $v
	 * @return     JCompetenceRessources The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setMatiere(Matiere $v = null)
	{
		if ($v === null) {
			$this->setMatiereId(NULL);
		} else {
			$this->setMatiereId($v->getId());
		}

		$this->aMatiere = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Matiere object, it will not be re-added.
		if ($v !== null) {
			$v->addJCompetenceRessources($this);
		}

		return $this;
	}


	/**
	 * Get the associated Matiere object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Matiere The associated Matiere object.
	 * @throws     PropelException
	 */
	public function getMatiere(PropelPDO $con = null)
	{
		if ($this->aMatiere === null && ($this->matiere_id !== null)) {
			$this->aMatiere = MatierePeer::retrieveByPK($this->matiere_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aMatiere->addJCompetenceRessourcess($this);
			 */
		}
		return $this->aMatiere;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aCompetence = null;
			$this->aRessource = null;
			$this->aMatiere = null;
	}

} // BaseJCompetenceRessources
