<?php

/**
 * Base class that represents a row from the 'exe_doc_questions' table.
 *
 * Liste des questions pour chaque document
 *
 * @package    competencesrb.om
 */
abstract class BaseJDocQuestion extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JDocQuestionPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the exe_doc_id field.
	 * @var        int
	 */
	protected $exe_doc_id;

	/**
	 * The value for the question field.
	 * @var        string
	 */
	protected $question;

	/**
	 * The value for the reponse field.
	 * @var        resource
	 */
	protected $reponse;

	/**
	 * The value for the voir_reponse field.
	 * @var        string
	 */
	protected $voir_reponse;

	/**
	 * The value for the aide field.
	 * @var        string
	 */
	protected $aide;

	/**
	 * The value for the affiche_aide field.
	 * @var        string
	 */
	protected $affiche_aide;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the created_on field.
	 * @var        int
	 */
	protected $created_on;

	/**
	 * @var        JExeDoc
	 */
	protected $aJExeDoc;

	/**
	 * @var        array JExeReponse[] Collection to store aggregation of JExeReponse objects.
	 */
	protected $collJExeReponses;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJExeReponses.
	 */
	private $lastJExeReponseCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJDocQuestion object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table exe_doc_questions
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [exe_doc_id] column value.
	 * cle etrangere du document
	 * @return     int
	 */
	public function getExeDocId()
	{
		return $this->exe_doc_id;
	}

	/**
	 * Get the [question] column value.
	 * Intitule de la question
	 * @return     string
	 */
	public function getQuestion()
	{
		return $this->question;
	}

	/**
	 * Get the [reponse] column value.
	 * reponse a la question
	 * @return     resource
	 */
	public function getReponse()
	{
		return $this->reponse;
	}

	/**
	 * Get the [voir_reponse] column value.
	 * Voir reponse ?
	 * @return     string
	 */
	public function getVoirReponse()
	{
		return $this->voir_reponse;
	}

	/**
	 * Get the [aide] column value.
	 * Contenu de l'aide
	 * @return     string
	 */
	public function getAide()
	{
		return $this->aide;
	}

	/**
	 * Get the [affiche_aide] column value.
	 * Afficher aide ?
	 * @return     string
	 */
	public function getAfficheAide()
	{
		return $this->affiche_aide;
	}

	/**
	 * Get the [rne] column value.
	 * Rne de l'etablissement
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table exe_doc_questions
	 * @param      int $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [exe_doc_id] column.
	 * cle etrangere du document
	 * @param      int $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setExeDocId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->exe_doc_id !== $v) {
			$this->exe_doc_id = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::EXE_DOC_ID;
		}

		if ($this->aJExeDoc !== null && $this->aJExeDoc->getId() !== $v) {
			$this->aJExeDoc = null;
		}

		return $this;
	} // setExeDocId()

	/**
	 * Set the value of [question] column.
	 * Intitule de la question
	 * @param      string $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setQuestion($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->question !== $v) {
			$this->question = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::QUESTION;
		}

		return $this;
	} // setQuestion()

	/**
	 * Set the value of [reponse] column.
	 * reponse a la question
	 * @param      resource $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setReponse($v)
	{
		// Because BLOB columns are streams in PDO we have to assume that they are
		// always modified when a new value is passed in.  For example, the contents
		// of the stream itself may have changed externally.
		if (!is_resource($v)) {
			$this->reponse = fopen('php://memory', 'r+');
			fwrite($this->reponse, $v);
			rewind($this->reponse);
		} else { // it's already a stream
			$this->reponse = $v;
		}
		$this->modifiedColumns[] = JDocQuestionPeer::REPONSE;

		return $this;
	} // setReponse()

	/**
	 * Set the value of [voir_reponse] column.
	 * Voir reponse ?
	 * @param      string $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setVoirReponse($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->voir_reponse !== $v) {
			$this->voir_reponse = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::VOIR_REPONSE;
		}

		return $this;
	} // setVoirReponse()

	/**
	 * Set the value of [aide] column.
	 * Contenu de l'aide
	 * @param      string $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setAide($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->aide !== $v) {
			$this->aide = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::AIDE;
		}

		return $this;
	} // setAide()

	/**
	 * Set the value of [affiche_aide] column.
	 * Afficher aide ?
	 * @param      string $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setAfficheAide($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->affiche_aide !== $v) {
			$this->affiche_aide = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::AFFICHE_AIDE;
		}

		return $this;
	} // setAfficheAide()

	/**
	 * Set the value of [rne] column.
	 * Rne de l'etablissement
	 * @param      string $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation
	 * @param      int $v new value
	 * @return     JDocQuestion The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v) {
			$this->created_on = $v;
			$this->modifiedColumns[] = JDocQuestionPeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->exe_doc_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->question = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			if ($row[$startcol + 3] !== null) {
				$this->reponse = fopen('php://memory', 'r+');
				fwrite($this->reponse, $row[$startcol + 3]);
				rewind($this->reponse);
			} else {
				$this->reponse = null;
			}
			$this->voir_reponse = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->aide = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->affiche_aide = ($row[$startcol + 6] !== null) ? (string) $row[$startcol + 6] : null;
			$this->rne = ($row[$startcol + 7] !== null) ? (string) $row[$startcol + 7] : null;
			$this->created_on = ($row[$startcol + 8] !== null) ? (int) $row[$startcol + 8] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 9; // 9 = JDocQuestionPeer::NUM_COLUMNS - JDocQuestionPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JDocQuestion object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aJExeDoc !== null && $this->exe_doc_id !== $this->aJExeDoc->getId()) {
			$this->aJExeDoc = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDocQuestionPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JDocQuestionPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aJExeDoc = null;
			$this->collJExeReponses = null;
			$this->lastJExeReponseCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDocQuestionPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JDocQuestionPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDocQuestionPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JDocQuestionPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aJExeDoc !== null) {
				if ($this->aJExeDoc->isModified() || $this->aJExeDoc->isNew()) {
					$affectedRows += $this->aJExeDoc->save($con);
				}
				$this->setJExeDoc($this->aJExeDoc);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = JDocQuestionPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JDocQuestionPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += JDocQuestionPeer::doUpdate($this, $con);
				}

				// Rewind the reponse LOB column, since PDO does not rewind after inserting value.
				if ($this->reponse !== null && is_resource($this->reponse)) {
					rewind($this->reponse);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJExeReponses !== null) {
				foreach ($this->collJExeReponses as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aJExeDoc !== null) {
				if (!$this->aJExeDoc->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aJExeDoc->getValidationFailures());
				}
			}


			if (($retval = JDocQuestionPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJExeReponses !== null) {
					foreach ($this->collJExeReponses as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JDocQuestionPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getExeDocId();
				break;
			case 2:
				return $this->getQuestion();
				break;
			case 3:
				return $this->getReponse();
				break;
			case 4:
				return $this->getVoirReponse();
				break;
			case 5:
				return $this->getAide();
				break;
			case 6:
				return $this->getAfficheAide();
				break;
			case 7:
				return $this->getRne();
				break;
			case 8:
				return $this->getCreatedOn();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JDocQuestionPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getExeDocId(),
			$keys[2] => $this->getQuestion(),
			$keys[3] => $this->getReponse(),
			$keys[4] => $this->getVoirReponse(),
			$keys[5] => $this->getAide(),
			$keys[6] => $this->getAfficheAide(),
			$keys[7] => $this->getRne(),
			$keys[8] => $this->getCreatedOn(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JDocQuestionPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setExeDocId($value);
				break;
			case 2:
				$this->setQuestion($value);
				break;
			case 3:
				$this->setReponse($value);
				break;
			case 4:
				$this->setVoirReponse($value);
				break;
			case 5:
				$this->setAide($value);
				break;
			case 6:
				$this->setAfficheAide($value);
				break;
			case 7:
				$this->setRne($value);
				break;
			case 8:
				$this->setCreatedOn($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JDocQuestionPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setExeDocId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setQuestion($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setReponse($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setVoirReponse($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setAide($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setAfficheAide($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setRne($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setCreatedOn($arr[$keys[8]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);

		if ($this->isColumnModified(JDocQuestionPeer::ID)) $criteria->add(JDocQuestionPeer::ID, $this->id);
		if ($this->isColumnModified(JDocQuestionPeer::EXE_DOC_ID)) $criteria->add(JDocQuestionPeer::EXE_DOC_ID, $this->exe_doc_id);
		if ($this->isColumnModified(JDocQuestionPeer::QUESTION)) $criteria->add(JDocQuestionPeer::QUESTION, $this->question);
		if ($this->isColumnModified(JDocQuestionPeer::REPONSE)) $criteria->add(JDocQuestionPeer::REPONSE, $this->reponse);
		if ($this->isColumnModified(JDocQuestionPeer::VOIR_REPONSE)) $criteria->add(JDocQuestionPeer::VOIR_REPONSE, $this->voir_reponse);
		if ($this->isColumnModified(JDocQuestionPeer::AIDE)) $criteria->add(JDocQuestionPeer::AIDE, $this->aide);
		if ($this->isColumnModified(JDocQuestionPeer::AFFICHE_AIDE)) $criteria->add(JDocQuestionPeer::AFFICHE_AIDE, $this->affiche_aide);
		if ($this->isColumnModified(JDocQuestionPeer::RNE)) $criteria->add(JDocQuestionPeer::RNE, $this->rne);
		if ($this->isColumnModified(JDocQuestionPeer::CREATED_ON)) $criteria->add(JDocQuestionPeer::CREATED_ON, $this->created_on);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);

		$criteria->add(JDocQuestionPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JDocQuestion (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setExeDocId($this->exe_doc_id);

		$copyObj->setQuestion($this->question);

		$copyObj->setReponse($this->reponse);

		$copyObj->setVoirReponse($this->voir_reponse);

		$copyObj->setAide($this->aide);

		$copyObj->setAfficheAide($this->affiche_aide);

		$copyObj->setRne($this->rne);

		$copyObj->setCreatedOn($this->created_on);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJExeReponses() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJExeReponse($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JDocQuestion Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JDocQuestionPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JDocQuestionPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a JExeDoc object.
	 *
	 * @param      JExeDoc $v
	 * @return     JDocQuestion The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setJExeDoc(JExeDoc $v = null)
	{
		if ($v === null) {
			$this->setExeDocId(NULL);
		} else {
			$this->setExeDocId($v->getId());
		}

		$this->aJExeDoc = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the JExeDoc object, it will not be re-added.
		if ($v !== null) {
			$v->addJDocQuestion($this);
		}

		return $this;
	}


	/**
	 * Get the associated JExeDoc object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     JExeDoc The associated JExeDoc object.
	 * @throws     PropelException
	 */
	public function getJExeDoc(PropelPDO $con = null)
	{
		if ($this->aJExeDoc === null && ($this->exe_doc_id !== null)) {
			$this->aJExeDoc = JExeDocPeer::retrieveByPK($this->exe_doc_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aJExeDoc->addJDocQuestions($this);
			 */
		}
		return $this->aJExeDoc;
	}

	/**
	 * Clears out the collJExeReponses collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJExeReponses()
	 */
	public function clearJExeReponses()
	{
		$this->collJExeReponses = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJExeReponses collection (array).
	 *
	 * By default this just sets the collJExeReponses collection to an empty array (like clearcollJExeReponses());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJExeReponses()
	{
		$this->collJExeReponses = array();
	}

	/**
	 * Gets an array of JExeReponse objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this JDocQuestion has previously been saved, it will retrieve
	 * related JExeReponses from storage. If this JDocQuestion is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JExeReponse[]
	 * @throws     PropelException
	 */
	public function getJExeReponses($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJExeReponses === null) {
			if ($this->isNew()) {
			   $this->collJExeReponses = array();
			} else {

				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				JExeReponsePeer::addSelectColumns($criteria);
				$this->collJExeReponses = JExeReponsePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				JExeReponsePeer::addSelectColumns($criteria);
				if (!isset($this->lastJExeReponseCriteria) || !$this->lastJExeReponseCriteria->equals($criteria)) {
					$this->collJExeReponses = JExeReponsePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJExeReponseCriteria = $criteria;
		return $this->collJExeReponses;
	}

	/**
	 * Returns the number of related JExeReponse objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JExeReponse objects.
	 * @throws     PropelException
	 */
	public function countJExeReponses(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJExeReponses === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				$count = JExeReponsePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				if (!isset($this->lastJExeReponseCriteria) || !$this->lastJExeReponseCriteria->equals($criteria)) {
					$count = JExeReponsePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJExeReponses);
				}
			} else {
				$count = count($this->collJExeReponses);
			}
		}
		$this->lastJExeReponseCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JExeReponse object to this object
	 * through the JExeReponse foreign key attribute.
	 *
	 * @param      JExeReponse $l JExeReponse
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJExeReponse(JExeReponse $l)
	{
		if ($this->collJExeReponses === null) {
			$this->initJExeReponses();
		}
		if (!in_array($l, $this->collJExeReponses, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJExeReponses, $l);
			$l->setJDocQuestion($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this JDocQuestion is new, it will return
	 * an empty collection; or if this JDocQuestion has previously
	 * been saved, it will retrieve related JExeReponses from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in JDocQuestion.
	 */
	public function getJExeReponsesJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJExeReponses === null) {
			if ($this->isNew()) {
				$this->collJExeReponses = array();
			} else {

				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				$this->collJExeReponses = JExeReponsePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

			if (!isset($this->lastJExeReponseCriteria) || !$this->lastJExeReponseCriteria->equals($criteria)) {
				$this->collJExeReponses = JExeReponsePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJExeReponseCriteria = $criteria;

		return $this->collJExeReponses;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this JDocQuestion is new, it will return
	 * an empty collection; or if this JDocQuestion has previously
	 * been saved, it will retrieve related JExeReponses from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in JDocQuestion.
	 */
	public function getJExeReponsesJoinExercice($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(JDocQuestionPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJExeReponses === null) {
			if ($this->isNew()) {
				$this->collJExeReponses = array();
			} else {

				$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

				$this->collJExeReponses = JExeReponsePeer::doSelectJoinExercice($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->id);

			if (!isset($this->lastJExeReponseCriteria) || !$this->lastJExeReponseCriteria->equals($criteria)) {
				$this->collJExeReponses = JExeReponsePeer::doSelectJoinExercice($criteria, $con, $join_behavior);
			}
		}
		$this->lastJExeReponseCriteria = $criteria;

		return $this->collJExeReponses;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJExeReponses) {
				foreach ((array) $this->collJExeReponses as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJExeReponses = null;
			$this->aJExeDoc = null;
	}

} // BaseJDocQuestion
