<?php

/**
 * Base class that represents a row from the 'matieres' table.
 *
 * Liste des matieres
 *
 * @package    competencesrb.om
 */
abstract class BaseMatiere extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        MatierePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nomcourt field.
	 * @var        string
	 */
	protected $nomcourt;

	/**
	 * The value for the nomlong field.
	 * @var        string
	 */
	protected $nomlong;

	/**
	 * @var        array Utilisateur[] Collection to store aggregation of Utilisateur objects.
	 */
	protected $collUtilisateurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collUtilisateurs.
	 */
	private $lastUtilisateurCriteria = null;

	/**
	 * @var        array Grille[] Collection to store aggregation of Grille objects.
	 */
	protected $collGrilles;

	/**
	 * @var        Criteria The criteria used to select the current contents of collGrilles.
	 */
	private $lastGrilleCriteria = null;

	/**
	 * @var        array Ressource[] Collection to store aggregation of Ressource objects.
	 */
	protected $collRessources;

	/**
	 * @var        Criteria The criteria used to select the current contents of collRessources.
	 */
	private $lastRessourceCriteria = null;

	/**
	 * @var        array JCompetenceRessources[] Collection to store aggregation of JCompetenceRessources objects.
	 */
	protected $collJCompetenceRessourcess;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetenceRessourcess.
	 */
	private $lastJCompetenceRessourcesCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseMatiere object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table matieres
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nomcourt] column value.
	 * Nom court de la matiere
	 * @return     string
	 */
	public function getNomcourt()
	{
		return $this->nomcourt;
	}

	/**
	 * Get the [nomlong] column value.
	 * Nom long de la matiere
	 * @return     string
	 */
	public function getNomlong()
	{
		return $this->nomlong;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table matieres
	 * @param      int $v new value
	 * @return     Matiere The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = MatierePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nomcourt] column.
	 * Nom court de la matiere
	 * @param      string $v new value
	 * @return     Matiere The current object (for fluent API support)
	 */
	public function setNomcourt($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomcourt !== $v) {
			$this->nomcourt = $v;
			$this->modifiedColumns[] = MatierePeer::NOMCOURT;
		}

		return $this;
	} // setNomcourt()

	/**
	 * Set the value of [nomlong] column.
	 * Nom long de la matiere
	 * @param      string $v new value
	 * @return     Matiere The current object (for fluent API support)
	 */
	public function setNomlong($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomlong !== $v) {
			$this->nomlong = $v;
			$this->modifiedColumns[] = MatierePeer::NOMLONG;
		}

		return $this;
	} // setNomlong()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nomcourt = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->nomlong = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 3; // 3 = MatierePeer::NUM_COLUMNS - MatierePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Matiere object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(MatierePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = MatierePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->collUtilisateurs = null;
			$this->lastUtilisateurCriteria = null;

			$this->collGrilles = null;
			$this->lastGrilleCriteria = null;

			$this->collRessources = null;
			$this->lastRessourceCriteria = null;

			$this->collJCompetenceRessourcess = null;
			$this->lastJCompetenceRessourcesCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(MatierePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			MatierePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(MatierePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			MatierePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			if ($this->isNew() ) {
				$this->modifiedColumns[] = MatierePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = MatierePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += MatierePeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collUtilisateurs !== null) {
				foreach ($this->collUtilisateurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collGrilles !== null) {
				foreach ($this->collGrilles as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collRessources !== null) {
				foreach ($this->collRessources as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetenceRessourcess !== null) {
				foreach ($this->collJCompetenceRessourcess as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			if (($retval = MatierePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collUtilisateurs !== null) {
					foreach ($this->collUtilisateurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collGrilles !== null) {
					foreach ($this->collGrilles as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collRessources !== null) {
					foreach ($this->collRessources as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetenceRessourcess !== null) {
					foreach ($this->collJCompetenceRessourcess as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = MatierePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNomcourt();
				break;
			case 2:
				return $this->getNomlong();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = MatierePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNomcourt(),
			$keys[2] => $this->getNomlong(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = MatierePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNomcourt($value);
				break;
			case 2:
				$this->setNomlong($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = MatierePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNomcourt($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setNomlong($arr[$keys[2]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(MatierePeer::DATABASE_NAME);

		if ($this->isColumnModified(MatierePeer::ID)) $criteria->add(MatierePeer::ID, $this->id);
		if ($this->isColumnModified(MatierePeer::NOMCOURT)) $criteria->add(MatierePeer::NOMCOURT, $this->nomcourt);
		if ($this->isColumnModified(MatierePeer::NOMLONG)) $criteria->add(MatierePeer::NOMLONG, $this->nomlong);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(MatierePeer::DATABASE_NAME);

		$criteria->add(MatierePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Matiere (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNomcourt($this->nomcourt);

		$copyObj->setNomlong($this->nomlong);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getUtilisateurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addUtilisateur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getGrilles() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addGrille($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getRessources() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addRessource($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetenceRessourcess() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetenceRessources($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Matiere Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     MatierePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new MatierePeer();
		}
		return self::$peer;
	}

	/**
	 * Clears out the collUtilisateurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addUtilisateurs()
	 */
	public function clearUtilisateurs()
	{
		$this->collUtilisateurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collUtilisateurs collection (array).
	 *
	 * By default this just sets the collUtilisateurs collection to an empty array (like clearcollUtilisateurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initUtilisateurs()
	{
		$this->collUtilisateurs = array();
	}

	/**
	 * Gets an array of Utilisateur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Matiere has previously been saved, it will retrieve
	 * related Utilisateurs from storage. If this Matiere is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Utilisateur[]
	 * @throws     PropelException
	 */
	public function getUtilisateurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
			   $this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				UtilisateurPeer::addSelectColumns($criteria);
				$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				UtilisateurPeer::addSelectColumns($criteria);
				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $this->collUtilisateurs;
	}

	/**
	 * Returns the number of related Utilisateur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Utilisateur objects.
	 * @throws     PropelException
	 */
	public function countUtilisateurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				$count = UtilisateurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$count = UtilisateurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collUtilisateurs);
				}
			} else {
				$count = count($this->collUtilisateurs);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Utilisateur object to this object
	 * through the Utilisateur foreign key attribute.
	 *
	 * @param      Utilisateur $l Utilisateur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addUtilisateur(Utilisateur $l)
	{
		if ($this->collUtilisateurs === null) {
			$this->initUtilisateurs();
		}
		if (!in_array($l, $this->collUtilisateurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collUtilisateurs, $l);
			$l->setMatiere($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getUtilisateursJoinetablissement($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getUtilisateursJoinrole($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getUtilisateursJoinClasse($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinClasse($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::MATIERE_ID, $this->id);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinClasse($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}

	/**
	 * Clears out the collGrilles collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addGrilles()
	 */
	public function clearGrilles()
	{
		$this->collGrilles = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collGrilles collection (array).
	 *
	 * By default this just sets the collGrilles collection to an empty array (like clearcollGrilles());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initGrilles()
	{
		$this->collGrilles = array();
	}

	/**
	 * Gets an array of Grille objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Matiere has previously been saved, it will retrieve
	 * related Grilles from storage. If this Matiere is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Grille[]
	 * @throws     PropelException
	 */
	public function getGrilles($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collGrilles === null) {
			if ($this->isNew()) {
			   $this->collGrilles = array();
			} else {

				$criteria->add(GrillePeer::MATIERE_ID, $this->id);

				GrillePeer::addSelectColumns($criteria);
				$this->collGrilles = GrillePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(GrillePeer::MATIERE_ID, $this->id);

				GrillePeer::addSelectColumns($criteria);
				if (!isset($this->lastGrilleCriteria) || !$this->lastGrilleCriteria->equals($criteria)) {
					$this->collGrilles = GrillePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastGrilleCriteria = $criteria;
		return $this->collGrilles;
	}

	/**
	 * Returns the number of related Grille objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Grille objects.
	 * @throws     PropelException
	 */
	public function countGrilles(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collGrilles === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(GrillePeer::MATIERE_ID, $this->id);

				$count = GrillePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(GrillePeer::MATIERE_ID, $this->id);

				if (!isset($this->lastGrilleCriteria) || !$this->lastGrilleCriteria->equals($criteria)) {
					$count = GrillePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collGrilles);
				}
			} else {
				$count = count($this->collGrilles);
			}
		}
		$this->lastGrilleCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Grille object to this object
	 * through the Grille foreign key attribute.
	 *
	 * @param      Grille $l Grille
	 * @return     void
	 * @throws     PropelException
	 */
	public function addGrille(Grille $l)
	{
		if ($this->collGrilles === null) {
			$this->initGrilles();
		}
		if (!in_array($l, $this->collGrilles, true)) { // only add it if the **same** object is not already associated
			array_push($this->collGrilles, $l);
			$l->setMatiere($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related Grilles from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getGrillesJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collGrilles === null) {
			if ($this->isNew()) {
				$this->collGrilles = array();
			} else {

				$criteria->add(GrillePeer::MATIERE_ID, $this->id);

				$this->collGrilles = GrillePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(GrillePeer::MATIERE_ID, $this->id);

			if (!isset($this->lastGrilleCriteria) || !$this->lastGrilleCriteria->equals($criteria)) {
				$this->collGrilles = GrillePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastGrilleCriteria = $criteria;

		return $this->collGrilles;
	}

	/**
	 * Clears out the collRessources collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addRessources()
	 */
	public function clearRessources()
	{
		$this->collRessources = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collRessources collection (array).
	 *
	 * By default this just sets the collRessources collection to an empty array (like clearcollRessources());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initRessources()
	{
		$this->collRessources = array();
	}

	/**
	 * Gets an array of Ressource objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Matiere has previously been saved, it will retrieve
	 * related Ressources from storage. If this Matiere is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Ressource[]
	 * @throws     PropelException
	 */
	public function getRessources($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collRessources === null) {
			if ($this->isNew()) {
			   $this->collRessources = array();
			} else {

				$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

				RessourcePeer::addSelectColumns($criteria);
				$this->collRessources = RessourcePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

				RessourcePeer::addSelectColumns($criteria);
				if (!isset($this->lastRessourceCriteria) || !$this->lastRessourceCriteria->equals($criteria)) {
					$this->collRessources = RessourcePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastRessourceCriteria = $criteria;
		return $this->collRessources;
	}

	/**
	 * Returns the number of related Ressource objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Ressource objects.
	 * @throws     PropelException
	 */
	public function countRessources(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collRessources === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

				$count = RessourcePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

				if (!isset($this->lastRessourceCriteria) || !$this->lastRessourceCriteria->equals($criteria)) {
					$count = RessourcePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collRessources);
				}
			} else {
				$count = count($this->collRessources);
			}
		}
		$this->lastRessourceCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Ressource object to this object
	 * through the Ressource foreign key attribute.
	 *
	 * @param      Ressource $l Ressource
	 * @return     void
	 * @throws     PropelException
	 */
	public function addRessource(Ressource $l)
	{
		if ($this->collRessources === null) {
			$this->initRessources();
		}
		if (!in_array($l, $this->collRessources, true)) { // only add it if the **same** object is not already associated
			array_push($this->collRessources, $l);
			$l->setMatiere($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related Ressources from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getRessourcesJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collRessources === null) {
			if ($this->isNew()) {
				$this->collRessources = array();
			} else {

				$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

				$this->collRessources = RessourcePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(RessourcePeer::MATIERE_ID, $this->id);

			if (!isset($this->lastRessourceCriteria) || !$this->lastRessourceCriteria->equals($criteria)) {
				$this->collRessources = RessourcePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastRessourceCriteria = $criteria;

		return $this->collRessources;
	}

	/**
	 * Clears out the collJCompetenceRessourcess collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetenceRessourcess()
	 */
	public function clearJCompetenceRessourcess()
	{
		$this->collJCompetenceRessourcess = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetenceRessourcess collection (array).
	 *
	 * By default this just sets the collJCompetenceRessourcess collection to an empty array (like clearcollJCompetenceRessourcess());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetenceRessourcess()
	{
		$this->collJCompetenceRessourcess = array();
	}

	/**
	 * Gets an array of JCompetenceRessources objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Matiere has previously been saved, it will retrieve
	 * related JCompetenceRessourcess from storage. If this Matiere is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetenceRessources[]
	 * @throws     PropelException
	 */
	public function getJCompetenceRessourcess($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
			   $this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				JCompetenceRessourcesPeer::addSelectColumns($criteria);
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				JCompetenceRessourcesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
					$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;
		return $this->collJCompetenceRessourcess;
	}

	/**
	 * Returns the number of related JCompetenceRessources objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetenceRessources objects.
	 * @throws     PropelException
	 */
	public function countJCompetenceRessourcess(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				$count = JCompetenceRessourcesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
					$count = JCompetenceRessourcesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetenceRessourcess);
				}
			} else {
				$count = count($this->collJCompetenceRessourcess);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetenceRessources object to this object
	 * through the JCompetenceRessources foreign key attribute.
	 *
	 * @param      JCompetenceRessources $l JCompetenceRessources
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetenceRessources(JCompetenceRessources $l)
	{
		if ($this->collJCompetenceRessourcess === null) {
			$this->initJCompetenceRessourcess();
		}
		if (!in_array($l, $this->collJCompetenceRessourcess, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetenceRessourcess, $l);
			$l->setMatiere($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related JCompetenceRessourcess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getJCompetenceRessourcessJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

			if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;

		return $this->collJCompetenceRessourcess;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Matiere is new, it will return
	 * an empty collection; or if this Matiere has previously
	 * been saved, it will retrieve related JCompetenceRessourcess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Matiere.
	 */
	public function getJCompetenceRessourcessJoinRessource($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(MatierePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinRessource($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceRessourcesPeer::MATIERE_ID, $this->id);

			if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinRessource($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;

		return $this->collJCompetenceRessourcess;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collUtilisateurs) {
				foreach ((array) $this->collUtilisateurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collGrilles) {
				foreach ((array) $this->collGrilles as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collRessources) {
				foreach ((array) $this->collRessources as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetenceRessourcess) {
				foreach ((array) $this->collJCompetenceRessourcess as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collUtilisateurs = null;
		$this->collGrilles = null;
		$this->collRessources = null;
		$this->collJCompetenceRessourcess = null;
	}

} // BaseMatiere
