<?php

/**
 * Base class that represents a row from the 'etablissements' table.
 *
 * Liste des etablissements
 *
 * @package    competencesrb.om
 */
abstract class Baseetablissement extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        etablissementPeer
	 */
	protected static $peer;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the nom field.
	 * Note: this column has a database default value of: 'user'
	 * @var        string
	 */
	protected $nom;

	/**
	 * The value for the adresse field.
	 * Note: this column has a database default value of: 'user'
	 * @var        string
	 */
	protected $adresse;

	/**
	 * The value for the codepostal field.
	 * Note: this column has a database default value of: 'user'
	 * @var        string
	 */
	protected $codepostal;

	/**
	 * The value for the commune field.
	 * Note: this column has a database default value of: 'user'
	 * @var        string
	 */
	protected $commune;

	/**
	 * @var        array Utilisateur[] Collection to store aggregation of Utilisateur objects.
	 */
	protected $collUtilisateurs;

	/**
	 * @var        Criteria The criteria used to select the current contents of collUtilisateurs.
	 */
	private $lastUtilisateurCriteria = null;

	/**
	 * @var        array Classe[] Collection to store aggregation of Classe objects.
	 */
	protected $collClasses;

	/**
	 * @var        Criteria The criteria used to select the current contents of collClasses.
	 */
	private $lastClasseCriteria = null;

	/**
	 * @var        array JCompetenceVisible[] Collection to store aggregation of JCompetenceVisible objects.
	 */
	protected $collJCompetenceVisibles;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetenceVisibles.
	 */
	private $lastJCompetenceVisibleCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of Baseetablissement object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->nom = 'user';
		$this->adresse = 'user';
		$this->codepostal = 'user';
		$this->commune = 'user';
	}

	/**
	 * Get the [rne] column value.
	 * cle primaire de la table etablissements
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [nom] column value.
	 * Nom de l'etablissement
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Get the [adresse] column value.
	 * Nom de l'etablissement
	 * @return     string
	 */
	public function getAdresse()
	{
		return $this->adresse;
	}

	/**
	 * Get the [codepostal] column value.
	 * Nom de l'etablissement
	 * @return     string
	 */
	public function getCodepostal()
	{
		return $this->codepostal;
	}

	/**
	 * Get the [commune] column value.
	 * Nom de l'etablissement
	 * @return     string
	 */
	public function getCommune()
	{
		return $this->commune;
	}

	/**
	 * Set the value of [rne] column.
	 * cle primaire de la table etablissements
	 * @param      string $v new value
	 * @return     etablissement The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = etablissementPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [nom] column.
	 * Nom de l'etablissement
	 * @param      string $v new value
	 * @return     etablissement The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v || $v === 'user') {
			$this->nom = $v;
			$this->modifiedColumns[] = etablissementPeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Set the value of [adresse] column.
	 * Nom de l'etablissement
	 * @param      string $v new value
	 * @return     etablissement The current object (for fluent API support)
	 */
	public function setAdresse($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->adresse !== $v || $v === 'user') {
			$this->adresse = $v;
			$this->modifiedColumns[] = etablissementPeer::ADRESSE;
		}

		return $this;
	} // setAdresse()

	/**
	 * Set the value of [codepostal] column.
	 * Nom de l'etablissement
	 * @param      string $v new value
	 * @return     etablissement The current object (for fluent API support)
	 */
	public function setCodepostal($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->codepostal !== $v || $v === 'user') {
			$this->codepostal = $v;
			$this->modifiedColumns[] = etablissementPeer::CODEPOSTAL;
		}

		return $this;
	} // setCodepostal()

	/**
	 * Set the value of [commune] column.
	 * Nom de l'etablissement
	 * @param      string $v new value
	 * @return     etablissement The current object (for fluent API support)
	 */
	public function setCommune($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->commune !== $v || $v === 'user') {
			$this->commune = $v;
			$this->modifiedColumns[] = etablissementPeer::COMMUNE;
		}

		return $this;
	} // setCommune()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(etablissementPeer::NOM,etablissementPeer::ADRESSE,etablissementPeer::CODEPOSTAL,etablissementPeer::COMMUNE))) {
				return false;
			}

			if ($this->nom !== 'user') {
				return false;
			}

			if ($this->adresse !== 'user') {
				return false;
			}

			if ($this->codepostal !== 'user') {
				return false;
			}

			if ($this->commune !== 'user') {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->rne = ($row[$startcol + 0] !== null) ? (string) $row[$startcol + 0] : null;
			$this->nom = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->adresse = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->codepostal = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->commune = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 5; // 5 = etablissementPeer::NUM_COLUMNS - etablissementPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating etablissement object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(etablissementPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = etablissementPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->collUtilisateurs = null;
			$this->lastUtilisateurCriteria = null;

			$this->collClasses = null;
			$this->lastClasseCriteria = null;

			$this->collJCompetenceVisibles = null;
			$this->lastJCompetenceVisibleCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(etablissementPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			etablissementPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(etablissementPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			etablissementPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;


			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = etablissementPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setNew(false);
				} else {
					$affectedRows += etablissementPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collUtilisateurs !== null) {
				foreach ($this->collUtilisateurs as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collClasses !== null) {
				foreach ($this->collClasses as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetenceVisibles !== null) {
				foreach ($this->collJCompetenceVisibles as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			if (($retval = etablissementPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collUtilisateurs !== null) {
					foreach ($this->collUtilisateurs as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collClasses !== null) {
					foreach ($this->collClasses as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetenceVisibles !== null) {
					foreach ($this->collJCompetenceVisibles as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = etablissementPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getRne();
				break;
			case 1:
				return $this->getNom();
				break;
			case 2:
				return $this->getAdresse();
				break;
			case 3:
				return $this->getCodepostal();
				break;
			case 4:
				return $this->getCommune();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = etablissementPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getRne(),
			$keys[1] => $this->getNom(),
			$keys[2] => $this->getAdresse(),
			$keys[3] => $this->getCodepostal(),
			$keys[4] => $this->getCommune(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = etablissementPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setRne($value);
				break;
			case 1:
				$this->setNom($value);
				break;
			case 2:
				$this->setAdresse($value);
				break;
			case 3:
				$this->setCodepostal($value);
				break;
			case 4:
				$this->setCommune($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = etablissementPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setRne($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNom($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setAdresse($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setCodepostal($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setCommune($arr[$keys[4]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(etablissementPeer::DATABASE_NAME);

		if ($this->isColumnModified(etablissementPeer::RNE)) $criteria->add(etablissementPeer::RNE, $this->rne);
		if ($this->isColumnModified(etablissementPeer::NOM)) $criteria->add(etablissementPeer::NOM, $this->nom);
		if ($this->isColumnModified(etablissementPeer::ADRESSE)) $criteria->add(etablissementPeer::ADRESSE, $this->adresse);
		if ($this->isColumnModified(etablissementPeer::CODEPOSTAL)) $criteria->add(etablissementPeer::CODEPOSTAL, $this->codepostal);
		if ($this->isColumnModified(etablissementPeer::COMMUNE)) $criteria->add(etablissementPeer::COMMUNE, $this->commune);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(etablissementPeer::DATABASE_NAME);

		$criteria->add(etablissementPeer::RNE, $this->rne);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     string
	 */
	public function getPrimaryKey()
	{
		return $this->getRne();
	}

	/**
	 * Generic method to set the primary key (rne column).
	 *
	 * @param      string $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setRne($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of etablissement (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setRne($this->rne);

		$copyObj->setNom($this->nom);

		$copyObj->setAdresse($this->adresse);

		$copyObj->setCodepostal($this->codepostal);

		$copyObj->setCommune($this->commune);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getUtilisateurs() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addUtilisateur($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getClasses() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addClasse($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetenceVisibles() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetenceVisible($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     etablissement Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     etablissementPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new etablissementPeer();
		}
		return self::$peer;
	}

	/**
	 * Clears out the collUtilisateurs collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addUtilisateurs()
	 */
	public function clearUtilisateurs()
	{
		$this->collUtilisateurs = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collUtilisateurs collection (array).
	 *
	 * By default this just sets the collUtilisateurs collection to an empty array (like clearcollUtilisateurs());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initUtilisateurs()
	{
		$this->collUtilisateurs = array();
	}

	/**
	 * Gets an array of Utilisateur objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this etablissement has previously been saved, it will retrieve
	 * related Utilisateurs from storage. If this etablissement is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Utilisateur[]
	 * @throws     PropelException
	 */
	public function getUtilisateurs($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
			   $this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				UtilisateurPeer::addSelectColumns($criteria);
				$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				UtilisateurPeer::addSelectColumns($criteria);
				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$this->collUtilisateurs = UtilisateurPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $this->collUtilisateurs;
	}

	/**
	 * Returns the number of related Utilisateur objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Utilisateur objects.
	 * @throws     PropelException
	 */
	public function countUtilisateurs(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				$count = UtilisateurPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
					$count = UtilisateurPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collUtilisateurs);
				}
			} else {
				$count = count($this->collUtilisateurs);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Utilisateur object to this object
	 * through the Utilisateur foreign key attribute.
	 *
	 * @param      Utilisateur $l Utilisateur
	 * @return     void
	 * @throws     PropelException
	 */
	public function addUtilisateur(Utilisateur $l)
	{
		if ($this->collUtilisateurs === null) {
			$this->initUtilisateurs();
		}
		if (!in_array($l, $this->collUtilisateurs, true)) { // only add it if the **same** object is not already associated
			array_push($this->collUtilisateurs, $l);
			$l->setetablissement($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this etablissement is new, it will return
	 * an empty collection; or if this etablissement has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in etablissement.
	 */
	public function getUtilisateursJoinrole($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::RNE, $this->rne);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinrole($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this etablissement is new, it will return
	 * an empty collection; or if this etablissement has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in etablissement.
	 */
	public function getUtilisateursJoinMatiere($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::RNE, $this->rne);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this etablissement is new, it will return
	 * an empty collection; or if this etablissement has previously
	 * been saved, it will retrieve related Utilisateurs from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in etablissement.
	 */
	public function getUtilisateursJoinClasse($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collUtilisateurs === null) {
			if ($this->isNew()) {
				$this->collUtilisateurs = array();
			} else {

				$criteria->add(UtilisateurPeer::RNE, $this->rne);

				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinClasse($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(UtilisateurPeer::RNE, $this->rne);

			if (!isset($this->lastUtilisateurCriteria) || !$this->lastUtilisateurCriteria->equals($criteria)) {
				$this->collUtilisateurs = UtilisateurPeer::doSelectJoinClasse($criteria, $con, $join_behavior);
			}
		}
		$this->lastUtilisateurCriteria = $criteria;

		return $this->collUtilisateurs;
	}

	/**
	 * Clears out the collClasses collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addClasses()
	 */
	public function clearClasses()
	{
		$this->collClasses = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collClasses collection (array).
	 *
	 * By default this just sets the collClasses collection to an empty array (like clearcollClasses());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initClasses()
	{
		$this->collClasses = array();
	}

	/**
	 * Gets an array of Classe objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this etablissement has previously been saved, it will retrieve
	 * related Classes from storage. If this etablissement is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Classe[]
	 * @throws     PropelException
	 */
	public function getClasses($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collClasses === null) {
			if ($this->isNew()) {
			   $this->collClasses = array();
			} else {

				$criteria->add(ClassePeer::RNE, $this->rne);

				ClassePeer::addSelectColumns($criteria);
				$this->collClasses = ClassePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(ClassePeer::RNE, $this->rne);

				ClassePeer::addSelectColumns($criteria);
				if (!isset($this->lastClasseCriteria) || !$this->lastClasseCriteria->equals($criteria)) {
					$this->collClasses = ClassePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastClasseCriteria = $criteria;
		return $this->collClasses;
	}

	/**
	 * Returns the number of related Classe objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Classe objects.
	 * @throws     PropelException
	 */
	public function countClasses(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collClasses === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(ClassePeer::RNE, $this->rne);

				$count = ClassePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(ClassePeer::RNE, $this->rne);

				if (!isset($this->lastClasseCriteria) || !$this->lastClasseCriteria->equals($criteria)) {
					$count = ClassePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collClasses);
				}
			} else {
				$count = count($this->collClasses);
			}
		}
		$this->lastClasseCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Classe object to this object
	 * through the Classe foreign key attribute.
	 *
	 * @param      Classe $l Classe
	 * @return     void
	 * @throws     PropelException
	 */
	public function addClasse(Classe $l)
	{
		if ($this->collClasses === null) {
			$this->initClasses();
		}
		if (!in_array($l, $this->collClasses, true)) { // only add it if the **same** object is not already associated
			array_push($this->collClasses, $l);
			$l->setetablissement($this);
		}
	}

	/**
	 * Clears out the collJCompetenceVisibles collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetenceVisibles()
	 */
	public function clearJCompetenceVisibles()
	{
		$this->collJCompetenceVisibles = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetenceVisibles collection (array).
	 *
	 * By default this just sets the collJCompetenceVisibles collection to an empty array (like clearcollJCompetenceVisibles());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetenceVisibles()
	{
		$this->collJCompetenceVisibles = array();
	}

	/**
	 * Gets an array of JCompetenceVisible objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this etablissement has previously been saved, it will retrieve
	 * related JCompetenceVisibles from storage. If this etablissement is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetenceVisible[]
	 * @throws     PropelException
	 */
	public function getJCompetenceVisibles($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
			   $this->collJCompetenceVisibles = array();
			} else {

				$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

				JCompetenceVisiblePeer::addSelectColumns($criteria);
				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

				JCompetenceVisiblePeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
					$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;
		return $this->collJCompetenceVisibles;
	}

	/**
	 * Returns the number of related JCompetenceVisible objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetenceVisible objects.
	 * @throws     PropelException
	 */
	public function countJCompetenceVisibles(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

				$count = JCompetenceVisiblePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

				if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
					$count = JCompetenceVisiblePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetenceVisibles);
				}
			} else {
				$count = count($this->collJCompetenceVisibles);
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetenceVisible object to this object
	 * through the JCompetenceVisible foreign key attribute.
	 *
	 * @param      JCompetenceVisible $l JCompetenceVisible
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetenceVisible(JCompetenceVisible $l)
	{
		if ($this->collJCompetenceVisibles === null) {
			$this->initJCompetenceVisibles();
		}
		if (!in_array($l, $this->collJCompetenceVisibles, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetenceVisibles, $l);
			$l->setetablissement($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this etablissement is new, it will return
	 * an empty collection; or if this etablissement has previously
	 * been saved, it will retrieve related JCompetenceVisibles from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in etablissement.
	 */
	public function getJCompetenceVisiblesJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(etablissementPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
				$this->collJCompetenceVisibles = array();
			} else {

				$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceVisiblePeer::RNE, $this->rne);

			if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;

		return $this->collJCompetenceVisibles;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collUtilisateurs) {
				foreach ((array) $this->collUtilisateurs as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collClasses) {
				foreach ((array) $this->collClasses as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetenceVisibles) {
				foreach ((array) $this->collJCompetenceVisibles as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collUtilisateurs = null;
		$this->collClasses = null;
		$this->collJCompetenceVisibles = null;
	}

} // Baseetablissement
