
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- utilisateurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS utilisateurs;


CREATE TABLE utilisateurs
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table utilisateurs',
	login VARCHAR(50)  NOT NULL COMMENT 'Login de l\'utilisateur',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	nom VARCHAR(50)  NOT NULL COMMENT 'Nom de l\'utilisateur',
	prenom VARCHAR(50)  NOT NULL COMMENT 'Prenom de l\'utilisateur',
	civilite VARCHAR(5)  NOT NULL COMMENT 'Civilite',
	naissance INTEGER(12)  NOT NULL COMMENT 'Date de naissance en timestamp UNIX',
	password VARCHAR(100)  NOT NULL COMMENT 'Mot de passe',
	email VARCHAR(100)  NOT NULL COMMENT 'Email de l\'utilisateur',
	role_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere du role de l\'utilisateur',
	matiere_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere de la matiere du professeur, nulle si pas un professeur',
	classe_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere de la classe, nulle si pas un eleve sauf PP',
	sso CHAR(1) default 'n' NOT NULL COMMENT 'Si acces possible en sso',
	PRIMARY KEY (id),
	INDEX utilisateurs_FI_1 (rne),
	CONSTRAINT utilisateurs_FK_1
		FOREIGN KEY (rne)
		REFERENCES etablissements (rne),
	INDEX utilisateurs_FI_2 (role_id),
	CONSTRAINT utilisateurs_FK_2
		FOREIGN KEY (role_id)
		REFERENCES roles (id),
	INDEX utilisateurs_FI_3 (matiere_id),
	CONSTRAINT utilisateurs_FK_3
		FOREIGN KEY (matiere_id)
		REFERENCES matieres (id),
	INDEX utilisateurs_FI_4 (classe_id),
	CONSTRAINT utilisateurs_FK_4
		FOREIGN KEY (classe_id)
		REFERENCES classes (id)
)Type=MyISAM COMMENT='utilisateurs';

#-----------------------------------------------------------------------------
#-- professeur_classes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS professeur_classes;


CREATE TABLE professeur_classes
(
	classe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la classe',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du professeur',
	PRIMARY KEY (classe_id,professeur_id),
	CONSTRAINT professeur_classes_FK_1
		FOREIGN KEY (classe_id)
		REFERENCES classes (id),
	INDEX professeur_classes_FI_2 (professeur_id),
	CONSTRAINT professeur_classes_FK_2
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des classes d\'un professeur';

#-----------------------------------------------------------------------------
#-- pp_classes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS pp_classes;


CREATE TABLE pp_classes
(
	classe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la classe',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du professeur',
	PRIMARY KEY (classe_id,professeur_id),
	CONSTRAINT pp_classes_FK_1
		FOREIGN KEY (classe_id)
		REFERENCES classes (id),
	INDEX pp_classes_FI_2 (professeur_id),
	CONSTRAINT pp_classes_FK_2
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des classes d\'un professeur';

#-----------------------------------------------------------------------------
#-- classes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS classes;


CREATE TABLE classes
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table classes',
	nom VARCHAR(50)  NOT NULL COMMENT 'nom de la classe',
	nomlong VARCHAR(50)  NOT NULL COMMENT 'nomlong de la classe',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	PRIMARY KEY (id),
	INDEX classes_FI_1 (rne),
	CONSTRAINT classes_FK_1
		FOREIGN KEY (rne)
		REFERENCES etablissements (rne)
)Type=MyISAM COMMENT='liste des classes';

#-----------------------------------------------------------------------------
#-- etablissements
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS etablissements;


CREATE TABLE etablissements
(
	rne VARCHAR(10)  NOT NULL COMMENT 'cle primaire de la table etablissements',
	nom VARCHAR(255) default 'user' NOT NULL COMMENT 'Nom de l\'etablissement',
	adresse VARCHAR(255) default 'user' NOT NULL COMMENT 'Nom de l\'etablissement',
	codepostal VARCHAR(255) default 'user' NOT NULL COMMENT 'Nom de l\'etablissement',
	commune VARCHAR(255) default 'user' NOT NULL COMMENT 'Nom de l\'etablissement',
	PRIMARY KEY (rne)
)Type=MyISAM COMMENT='Liste des etablissements';

#-----------------------------------------------------------------------------
#-- roles
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS roles;


CREATE TABLE roles
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table roles',
	nom VARCHAR(50) default 'user' NOT NULL COMMENT 'Nom du role',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Liste des roles possibles pour les utilisateurs';

#-----------------------------------------------------------------------------
#-- droits
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS droits;


CREATE TABLE droits
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table droits',
	role_id VARCHAR(50)  NOT NULL COMMENT 'role concerne',
	module VARCHAR(100) default '' NOT NULL COMMENT 'Nom du module',
	controleur VARCHAR(100)  NOT NULL COMMENT 'Nom du controleur',
	action VARCHAR(100) default 'index' NOT NULL COMMENT 'action autorisee',
	PRIMARY KEY (id),
	INDEX droits_FI_1 (role_id),
	CONSTRAINT droits_FK_1
		FOREIGN KEY (role_id)
		REFERENCES roles (id)
)Type=MyISAM COMMENT='Liste des droits pour chaque role';

#-----------------------------------------------------------------------------
#-- logs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS logs;


CREATE TABLE logs
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table logs',
	type VARCHAR(30) default 'session' NOT NULL COMMENT 'Type de log',
	degre INTEGER(3) default 0 NOT NULL COMMENT 'Degre de gravite',
	texte VARCHAR(255)  NOT NULL COMMENT 'Description du log',
	debut INTEGER(12)  NOT NULL COMMENT 'timestamp UNIX du debut',
	fin INTEGER(12)  NOT NULL COMMENT 'timestamp UNIX de la fin',
	ip VARCHAR(30) default '0' NOT NULL COMMENT 'Adresse IP de l\'utilisateur',
	navigateur VARCHAR(255) default 'inconnu' NOT NULL COMMENT 'Type de navigateur',
	marqueur VARCHAR(30) default '0' NOT NULL COMMENT 'Marqueur le temps de la session',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur logue',
	PRIMARY KEY (id),
	INDEX logs_FI_1 (utilisateur_id),
	CONSTRAINT logs_FK_1
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Logs de connexion';

#-----------------------------------------------------------------------------
#-- settings
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS settings;


CREATE TABLE settings
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table settings',
	nom VARCHAR(100)  NOT NULL COMMENT 'Nom du reglage',
	valeur VARCHAR(100)  NOT NULL COMMENT 'Valeur de ce reglage',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Reglages de l\'interface';

#-----------------------------------------------------------------------------
#-- questions
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS questions;


CREATE TABLE questions
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table questions',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	contenu LONGTEXT  NOT NULL COMMENT 'Contenu de la question',
	created_on INTEGER(11) default 0 NOT NULL COMMENT 'Date de creation, timestamp UNIX',
	updated_on INTEGER(11) default 0 NOT NULL COMMENT 'Date de modification, timestamp UNIX',
	PRIMARY KEY (id),
	INDEX questions_FI_1 (utilisateur_id),
	CONSTRAINT questions_FK_1
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des questions posees';

#-----------------------------------------------------------------------------
#-- reponses
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS reponses;


CREATE TABLE reponses
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table questions',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	question_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la question',
	contenu LONGTEXT  NOT NULL COMMENT 'Contenu de la question',
	created_on INTEGER(11) default 0 NOT NULL COMMENT 'Date de creation, timestamp UNIX',
	updated_on INTEGER(11) default 0 NOT NULL COMMENT 'Date de modification, timestamp UNIX',
	PRIMARY KEY (id),
	INDEX reponses_FI_1 (utilisateur_id),
	CONSTRAINT reponses_FK_1
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id),
	INDEX reponses_FI_2 (question_id),
	CONSTRAINT reponses_FK_2
		FOREIGN KEY (question_id)
		REFERENCES questions (id)
)Type=MyISAM COMMENT='Liste des reponses aux questions posees';

#-----------------------------------------------------------------------------
#-- matieres
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS matieres;


CREATE TABLE matieres
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table matieres',
	nomcourt VARCHAR(255)  NOT NULL COMMENT 'Nom court de la matiere',
	nomlong VARCHAR(255)  NOT NULL COMMENT 'Nom long de la matiere',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Liste des matieres';

#-----------------------------------------------------------------------------
#-- cptcegrps
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS cptcegrps;


CREATE TABLE cptcegrps
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table cptcegrps',
	ordre INTEGER(11)  NOT NULL COMMENT 'Ordre d\'affichage de ces groupes de compétences (tronc commun)',
	nom VARCHAR(255)  NOT NULL COMMENT 'Nom du grp',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Les principaux themes de competence du tronc commun';

#-----------------------------------------------------------------------------
#-- competences
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS competences;


CREATE TABLE competences
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table competences',
	nomcourt VARCHAR(255)  NOT NULL COMMENT 'Nom court de la competence',
	nomlong VARCHAR(255)  NOT NULL COMMENT 'Nom long de la competence',
	rne VARCHAR(10) default 'all' NOT NULL COMMENT 'Etablissement de la cptce, all si pour tous etab',
	cptcegrp_id INTEGER(11)  NOT NULL COMMENT 'Domaine de la competence',
	competence_id INTEGER(11) default 0 NOT NULL COMMENT 'Permet de lier des competences entre elles',
	type CHAR(20) default 'perso' NOT NULL COMMENT 'Type de competence :tronc peda perso',
	niveau INTEGER(1) default 3 NOT NULL COMMENT 'Niveau de hiérarchie des competences : 1 = socle, 2 = derivee du socle, 3 = les autres',
	utilisateur_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere de l\'utilisateur dans le cas d\'une competence perso',
	PRIMARY KEY (id),
	INDEX competences_FI_1 (cptcegrp_id),
	CONSTRAINT competences_FK_1
		FOREIGN KEY (cptcegrp_id)
		REFERENCES cptcegrps (id),
	INDEX competences_FI_2 (competence_id),
	CONSTRAINT competences_FK_2
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX competences_FI_3 (utilisateur_id),
	CONSTRAINT competences_FK_3
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des competences evaluees';

#-----------------------------------------------------------------------------
#-- competences_professeurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS competences_professeurs;


CREATE TABLE competences_professeurs
(
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la competence',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur professeur',
	PRIMARY KEY (competence_id,professeur_id),
	CONSTRAINT competences_professeurs_FK_1
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX competences_professeurs_FI_2 (professeur_id),
	CONSTRAINT competences_professeurs_FK_2
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Toutes les competences peda sont rattachees a des professeurs';

#-----------------------------------------------------------------------------
#-- competence_visible
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS competence_visible;


CREATE TABLE competence_visible
(
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la competence',
	rne VARCHAR(10)  NOT NULL COMMENT 'cle etrangere de l\'etablissement',
	visible CHAR(1)  NOT NULL COMMENT 'O/N visible ou pas',
	PRIMARY KEY (competence_id,rne),
	CONSTRAINT competence_visible_FK_1
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX competence_visible_FI_2 (rne),
	CONSTRAINT competence_visible_FK_2
		FOREIGN KEY (rne)
		REFERENCES etablissements (rne)
)Type=MyISAM COMMENT='Permet a un etablissement de rendre invisible certaines competences';

#-----------------------------------------------------------------------------
#-- cptcegrp_utilisateurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS cptcegrp_utilisateurs;


CREATE TABLE cptcegrp_utilisateurs
(
	cptcegrp_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la cptcegrps',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	PRIMARY KEY (cptcegrp_id,utilisateur_id),
	CONSTRAINT cptcegrp_utilisateurs_FK_1
		FOREIGN KEY (cptcegrp_id)
		REFERENCES cptcegrps (id),
	INDEX cptcegrp_utilisateurs_FI_2 (utilisateur_id),
	CONSTRAINT cptcegrp_utilisateurs_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Permet a un utilisateur de ne choisir d\'afficher que les competences des grp qu\'il veut';

#-----------------------------------------------------------------------------
#-- grilles
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS grilles;


CREATE TABLE grilles
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table grilles',
	nom VARCHAR(255)  NOT NULL COMMENT 'Nom de la grille',
	type CHAR(5)  NOT NULL COMMENT 'Type : peda perso',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	matiere_id INTEGER(11)  NOT NULL COMMENT 'Matiere de la grille',
	created_on INTEGER(11) default 0 NOT NULL COMMENT 'Date de creation, timestamp UNIX',
	utilisateur_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere de l\'utilisateur si type = perso',
	PRIMARY KEY (id),
	INDEX grilles_FI_1 (matiere_id),
	CONSTRAINT grilles_FK_1
		FOREIGN KEY (matiere_id)
		REFERENCES matieres (id),
	INDEX grilles_FI_2 (utilisateur_id),
	CONSTRAINT grilles_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des grilles de competences';

#-----------------------------------------------------------------------------
#-- grille_competences
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS grille_competences;


CREATE TABLE grille_competences
(
	grille_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la grille',
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la competence',
	PRIMARY KEY (grille_id,competence_id),
	CONSTRAINT grille_competences_FK_1
		FOREIGN KEY (grille_id)
		REFERENCES grilles (id),
	INDEX grille_competences_FI_2 (competence_id),
	CONSTRAINT grille_competences_FK_2
		FOREIGN KEY (competence_id)
		REFERENCES competences (id)
)Type=MyISAM COMMENT='Liste des competences rattachees a une grille';

#-----------------------------------------------------------------------------
#-- grille_utilisateurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS grille_utilisateurs;


CREATE TABLE grille_utilisateurs
(
	grille_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la grille',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	PRIMARY KEY (grille_id,utilisateur_id),
	CONSTRAINT grille_utilisateurs_FK_1
		FOREIGN KEY (grille_id)
		REFERENCES grilles (id),
	INDEX grille_utilisateurs_FI_2 (utilisateur_id),
	CONSTRAINT grille_utilisateurs_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des grilles utilisees par un utilisateur';

#-----------------------------------------------------------------------------
#-- grille_groupes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS grille_groupes;


CREATE TABLE grille_groupes
(
	grille_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la grille',
	groupe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du groupe',
	PRIMARY KEY (grille_id,groupe_id),
	CONSTRAINT grille_groupes_FK_1
		FOREIGN KEY (grille_id)
		REFERENCES grilles (id),
	INDEX grille_groupes_FI_2 (groupe_id),
	CONSTRAINT grille_groupes_FK_2
		FOREIGN KEY (groupe_id)
		REFERENCES groupes (id)
)Type=MyISAM COMMENT='Groupe (eleves) rattache a une grille';

#-----------------------------------------------------------------------------
#-- controles
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS controles;


CREATE TABLE controles
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table controles',
	nomcourt VARCHAR(255)  NOT NULL COMMENT 'Nom court du controle',
	nomlong VARCHAR(255)  NOT NULL COMMENT 'Nom long du controle',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	grille_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la grille',
	groupe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du groupe',
	created_on INTEGER(12)  NOT NULL COMMENT 'Date de creation du controle',
	PRIMARY KEY (id),
	INDEX controles_FI_1 (grille_id),
	CONSTRAINT controles_FK_1
		FOREIGN KEY (grille_id)
		REFERENCES grilles (id),
	INDEX controles_FI_2 (groupe_id),
	CONSTRAINT controles_FK_2
		FOREIGN KEY (groupe_id)
		REFERENCES groupes (id)
)Type=MyISAM COMMENT='Liste des controles';

#-----------------------------------------------------------------------------
#-- controle_possesseurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS controle_possesseurs;


CREATE TABLE controle_possesseurs
(
	controle_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du controle',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur professeur',
	PRIMARY KEY (controle_id,utilisateur_id),
	CONSTRAINT controle_possesseurs_FK_1
		FOREIGN KEY (controle_id)
		REFERENCES controles (id),
	INDEX controle_possesseurs_FI_2 (utilisateur_id),
	CONSTRAINT controle_possesseurs_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des possesseurs de chaque controle';

#-----------------------------------------------------------------------------
#-- controle_resultats
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS controle_resultats;


CREATE TABLE controle_resultats
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table controle_resultats',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	controle_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du controle',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur eleve',
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la competence',
	resultat CHAR(2)  NOT NULL COMMENT 'resultat de la competence',
	PRIMARY KEY (id),
	INDEX controle_resultats_FI_1 (controle_id),
	CONSTRAINT controle_resultats_FK_1
		FOREIGN KEY (controle_id)
		REFERENCES controles (id),
	INDEX controle_resultats_FI_2 (utilisateur_id),
	CONSTRAINT controle_resultats_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id),
	INDEX controle_resultats_FI_3 (competence_id),
	CONSTRAINT controle_resultats_FK_3
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX controle_resultats_FI_4 (resultat),
	CONSTRAINT controle_resultats_FK_4
		FOREIGN KEY (resultat)
		REFERENCES validations (lettre)
)Type=MyISAM COMMENT='Resultat de l\'evaluation de chaque competence pour chaque controle';

#-----------------------------------------------------------------------------
#-- validations
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS validations;


CREATE TABLE validations
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table validations',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	lettre CHAR(2)  NOT NULL COMMENT 'Lettre de la validation',
	texte VARCHAR(100)  NOT NULL COMMENT 'texte de la validation',
	couleur CHAR(11)  NOT NULL COMMENT 'Couleur de la validation en hexadecimal',
	niveau INTEGER(2)  NOT NULL COMMENT 'Niveau de la validation',
	PRIMARY KEY (id,lettre),
	INDEX I_referenced_controle_resultats_FK_4_1 (lettre),
	INDEX I_referenced_bilans_FK_4_2 (lettre)
)Type=MyISAM COMMENT='Liste des niveaux de validation';

#-----------------------------------------------------------------------------
#-- groupes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS groupes;


CREATE TABLE groupes
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table groupes',
	nomcourt VARCHAR(255)  NOT NULL COMMENT 'Nom court du groupe',
	nomlong VARCHAR(255)  NOT NULL COMMENT 'Nom long du groupe',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Liste des groupes';

#-----------------------------------------------------------------------------
#-- groupe_possesseurs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS groupe_possesseurs;


CREATE TABLE groupe_possesseurs
(
	groupe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du groupe',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	PRIMARY KEY (groupe_id,utilisateur_id),
	CONSTRAINT groupe_possesseurs_FK_1
		FOREIGN KEY (groupe_id)
		REFERENCES groupes (id),
	INDEX groupe_possesseurs_FI_2 (utilisateur_id),
	CONSTRAINT groupe_possesseurs_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des possesseurs de chaque groupe';

#-----------------------------------------------------------------------------
#-- groupe_eleves
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS groupe_eleves;


CREATE TABLE groupe_eleves
(
	groupe_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du groupe',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	PRIMARY KEY (groupe_id,utilisateur_id),
	CONSTRAINT groupe_eleves_FK_1
		FOREIGN KEY (groupe_id)
		REFERENCES groupes (id),
	INDEX groupe_eleves_FI_2 (utilisateur_id),
	CONSTRAINT groupe_eleves_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des eleves de chaque groupe';

#-----------------------------------------------------------------------------
#-- bulletins
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS bulletins;


CREATE TABLE bulletins
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table bulletins',
	nom VARCHAR(255)  NOT NULL COMMENT 'Nom du bulletin',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	debut INTEGER(11)  NOT NULL COMMENT 'Date de debut de la periode des bilans du bulletin',
	fin INTEGER(11)  NOT NULL COMMENT 'Date de debut de la periode des bilans du bulletin',
	ferme CHAR(1) default 'N' NOT NULL COMMENT 'si `ferme` est à O, les controle d\'avant sont fermes aussi',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation du bulletin',
	classe_id INTEGER(11)  NOT NULL COMMENT 'classe concernee par ce bulletin',
	PRIMARY KEY (id),
	INDEX bulletins_FI_1 (classe_id),
	CONSTRAINT bulletins_FK_1
		FOREIGN KEY (classe_id)
		REFERENCES classes (id)
)Type=MyISAM COMMENT='Liste des bulletins';

#-----------------------------------------------------------------------------
#-- bulletin_transversales
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS bulletin_transversales;


CREATE TABLE bulletin_transversales
(
	bulletin_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table bulletins',
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table competences',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	PRIMARY KEY (bulletin_id,competence_id),
	CONSTRAINT bulletin_transversales_FK_1
		FOREIGN KEY (bulletin_id)
		REFERENCES bulletins (id),
	INDEX bulletin_transversales_FI_2 (competence_id),
	CONSTRAINT bulletin_transversales_FK_2
		FOREIGN KEY (competence_id)
		REFERENCES competences (id)
)Type=MyISAM COMMENT='Liste des competences transversales de ce bulletin';

#-----------------------------------------------------------------------------
#-- bilans
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS bilans;


CREATE TABLE bilans
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table bilans',
	nom VARCHAR(255)  NOT NULL COMMENT 'Nom du bilan',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	date INTEGER(11)  NOT NULL COMMENT 'Date du bilan (pour les bulletins)',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation du bilan (automatique)',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur professeur',
	transversale CHAR(1) default 'N' NOT NULL COMMENT 'tag pour savoir s\'il s\'agit de competence transversale',
	eleve_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur eleve',
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la competence',
	resultat CHAR(2)  NOT NULL COMMENT 'resultat du bilan de la competence',
	appreciation VARCHAR(255)  NOT NULL COMMENT 'appreciation du bilan de la competence',
	PRIMARY KEY (id),
	INDEX bilans_FI_1 (professeur_id),
	CONSTRAINT bilans_FK_1
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id),
	INDEX bilans_FI_2 (eleve_id),
	CONSTRAINT bilans_FK_2
		FOREIGN KEY (eleve_id)
		REFERENCES utilisateurs (id),
	INDEX bilans_FI_3 (competence_id),
	CONSTRAINT bilans_FK_3
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX bilans_FI_4 (resultat),
	CONSTRAINT bilans_FK_4
		FOREIGN KEY (resultat)
		REFERENCES validations (lettre)
)Type=MyISAM COMMENT='Liste des bilans';

#-----------------------------------------------------------------------------
#-- appreciations
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS appreciations;


CREATE TABLE appreciations
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table appreciations',
	bulletin_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du bulletin',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur professeur',
	eleve_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur eleve',
	transversale CHAR(1)  NOT NULL COMMENT 'Transversale ou pas (O/N)',
	contenu TEXT  NOT NULL COMMENT 'Contenu de l\'appreciation',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation de l\'appreciation',
	moyennecrite INTEGER(11)  NOT NULL COMMENT 'inutile',
	moyenneorale INTEGER(11)  NOT NULL COMMENT 'inutile',
	PRIMARY KEY (id),
	INDEX appreciations_FI_1 (bulletin_id),
	CONSTRAINT appreciations_FK_1
		FOREIGN KEY (bulletin_id)
		REFERENCES bulletins (id),
	INDEX appreciations_FI_2 (professeur_id),
	CONSTRAINT appreciations_FK_2
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id),
	INDEX appreciations_FI_3 (eleve_id),
	CONSTRAINT appreciations_FK_3
		FOREIGN KEY (eleve_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des appreciations pour chaque matiere';

#-----------------------------------------------------------------------------
#-- appreciation_bilans
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS appreciation_bilans;


CREATE TABLE appreciation_bilans
(
	appreciation_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'appreciation',
	bilan_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du bilan',
	PRIMARY KEY (appreciation_id,bilan_id),
	CONSTRAINT appreciation_bilans_FK_1
		FOREIGN KEY (appreciation_id)
		REFERENCES appreciations (id),
	INDEX appreciation_bilans_FI_2 (bilan_id),
	CONSTRAINT appreciation_bilans_FK_2
		FOREIGN KEY (bilan_id)
		REFERENCES bilans (id)
)Type=MyISAM COMMENT='Liste des bilans de chaque appreciation';

#-----------------------------------------------------------------------------
#-- periodes
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS periodes;


CREATE TABLE periodes
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table periodes',
	nom VARCHAR(255)  NOT NULL COMMENT 'Nom de la periode',
	rne VARCHAR(10)  NOT NULL COMMENT 'Etablissement de l\'utilisateur',
	debut INTEGER(11)  NOT NULL COMMENT 'debut de la periode',
	fin INTEGER(11)  NOT NULL COMMENT 'fin de la periode',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Liste des periode de l\'annee';

#-----------------------------------------------------------------------------
#-- aides
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS aides;


CREATE TABLE aides
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table aides',
	module VARCHAR(100) default '' NOT NULL COMMENT 'Module de l\'application',
	controleur VARCHAR(100)  NOT NULL COMMENT 'Controleur',
	vue VARCHAR(100)  NOT NULL COMMENT 'Vue',
	contenu LONGTEXT  NOT NULL COMMENT 'contenu de l\'aide',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Ensemble des aides';

#-----------------------------------------------------------------------------
#-- d_discussions
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS d_discussions;


CREATE TABLE d_discussions
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table d_discussions',
	nom VARCHAR(255) default '' NOT NULL COMMENT 'Nom de la discussion',
	debut INTEGER(11)  NOT NULL COMMENT 'Date de debut de la discussion',
	fin INTEGER(11)  NOT NULL COMMENT 'Date de fin de la discussion',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation de la discussion',
	ordredujour LONGTEXT  NOT NULL COMMENT 'Ordre du jour',
	PRIMARY KEY (id)
)Type=MyISAM COMMENT='Liste des discussion';

#-----------------------------------------------------------------------------
#-- d_discussion_membre
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS d_discussion_membre;


CREATE TABLE d_discussion_membre
(
	discussion_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table d_discussions',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	connecte CHAR(1) default 'N' NOT NULL COMMENT 'O si l\'utilisateur est connecte N sinon',
	connecte_date INTEGER(11)  NOT NULL COMMENT 'Date de l\'acceptation de la connexion',
	refuse CHAR(1) default 'N' NOT NULL COMMENT 'Un membre peut refuser la connexion',
	PRIMARY KEY (discussion_id,utilisateur_id),
	CONSTRAINT d_discussion_membre_FK_1
		FOREIGN KEY (discussion_id)
		REFERENCES d_discussions (id),
	INDEX d_discussion_membre_FI_2 (utilisateur_id),
	CONSTRAINT d_discussion_membre_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des membres de la discussion';

#-----------------------------------------------------------------------------
#-- d_echanges
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS d_echanges;


CREATE TABLE d_echanges
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table d_echanges',
	discussion_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table d_discussions',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	phrase VARCHAR(255) default '' NOT NULL COMMENT 'Phrase ecrite par les echangeurs',
	PRIMARY KEY (id),
	INDEX d_echanges_FI_1 (discussion_id),
	CONSTRAINT d_echanges_FK_1
		FOREIGN KEY (discussion_id)
		REFERENCES d_discussions (id),
	INDEX d_echanges_FI_2 (utilisateur_id),
	CONSTRAINT d_echanges_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des echanges';

#-----------------------------------------------------------------------------
#-- d_documents
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS d_documents;


CREATE TABLE d_documents
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table d_documents',
	discussion_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table d_discussions',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	nom VARCHAR(255) default '' NOT NULL COMMENT 'nom du document',
	chemin VARCHAR(255) default '' NOT NULL COMMENT 'chemin du document',
	PRIMARY KEY (id),
	INDEX d_documents_FI_1 (discussion_id),
	CONSTRAINT d_documents_FK_1
		FOREIGN KEY (discussion_id)
		REFERENCES d_discussions (id),
	INDEX d_documents_FI_2 (utilisateur_id),
	CONSTRAINT d_documents_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des documents echanges pendant la discussion';

#-----------------------------------------------------------------------------
#-- ressources
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS ressources;


CREATE TABLE ressources
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table ressources',
	designation VARCHAR(255)  NOT NULL COMMENT 'Designation de la ressource',
	adresse VARCHAR(255)  NOT NULL COMMENT 'adresse de la ressource',
	type CHAR(4) default '' NOT NULL COMMENT 'Type de document : url/doc/html',
	matiere_id INTEGER(11) default 0 NOT NULL COMMENT 'cle etrangere de la matiere, nulle si transdisciplinaire',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement de cette ressource',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation de la ressource',
	utilisateur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'utilisateur',
	PRIMARY KEY (id),
	INDEX ressources_FI_1 (matiere_id),
	CONSTRAINT ressources_FK_1
		FOREIGN KEY (matiere_id)
		REFERENCES matieres (id),
	INDEX ressources_FI_2 (utilisateur_id),
	CONSTRAINT ressources_FK_2
		FOREIGN KEY (utilisateur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des ressources disponibles';

#-----------------------------------------------------------------------------
#-- competence_ressources
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS competence_ressources;


CREATE TABLE competence_ressources
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table competence_ressources',
	competence_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la table competences',
	ressource_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la ressource',
	validation CHAR(1)  NOT NULL COMMENT 'Pour quel niveau de validation ? on stocke la lettre',
	matiere_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la matiere',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement de cette association competence-ressource',
	PRIMARY KEY (id),
	INDEX competence_ressources_FI_1 (competence_id),
	CONSTRAINT competence_ressources_FK_1
		FOREIGN KEY (competence_id)
		REFERENCES competences (id),
	INDEX competence_ressources_FI_2 (ressource_id),
	CONSTRAINT competence_ressources_FK_2
		FOREIGN KEY (ressource_id)
		REFERENCES ressources (id),
	INDEX competence_ressources_FI_3 (matiere_id),
	CONSTRAINT competence_ressources_FK_3
		FOREIGN KEY (matiere_id)
		REFERENCES matieres (id)
)Type=MyISAM COMMENT='Quelle ressource pour quelle competence ?';

#-----------------------------------------------------------------------------
#-- attestations
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS attestations;


CREATE TABLE attestations
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table attestations',
	eleve_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'eleve',
	pallier INTEGER(1)  NOT NULL COMMENT 'Pallier 1,  2 ou 3',
	assr1 CHAR(1) default '' NOT NULL COMMENT 'ASSR 1 o/n',
	assr2 CHAR(1) default '' NOT NULL COMMENT 'ASSR 2 o/n',
	psc1 CHAR(1) default '' NOT NULL COMMENT 'PSC 1 o/n',
	maitrise CHAR(1) default '' NOT NULL COMMENT 'maitrise o/n',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	PRIMARY KEY (id),
	INDEX attestations_FI_1 (eleve_id),
	CONSTRAINT attestations_FK_1
		FOREIGN KEY (eleve_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des attestations';

#-----------------------------------------------------------------------------
#-- attestation_items
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS attestation_items;


CREATE TABLE attestation_items
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table attestations',
	attestation_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'attestation',
	cptcegrp_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du domaine',
	item VARCHAR(255) default 'n' NOT NULL COMMENT 'Nom de l\'item',
	maitrise CHAR(1) default '' NOT NULL COMMENT 'maitrise o/n',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	PRIMARY KEY (id),
	INDEX attestation_items_FI_1 (attestation_id),
	CONSTRAINT attestation_items_FK_1
		FOREIGN KEY (attestation_id)
		REFERENCES attestations (id),
	INDEX attestation_items_FI_2 (cptcegrp_id),
	CONSTRAINT attestation_items_FK_2
		FOREIGN KEY (cptcegrp_id)
		REFERENCES cptcegrps (id)
)Type=MyISAM COMMENT='Liste des items de chaque attestation';

#-----------------------------------------------------------------------------
#-- exercices
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS exercices;


CREATE TABLE exercices
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table exercices',
	titre VARCHAR(255)  NOT NULL COMMENT 'Titre de l\'exercice',
	consigne TEXT  NOT NULL COMMENT 'consignes de travail',
	nbre_docs CHAR(2)  NOT NULL COMMENT 'Nombre de documents',
	professeur_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du professeur',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	PRIMARY KEY (id),
	INDEX exercices_FI_1 (professeur_id),
	CONSTRAINT exercices_FK_1
		FOREIGN KEY (professeur_id)
		REFERENCES utilisateurs (id)
)Type=MyISAM COMMENT='Liste des exercices';

#-----------------------------------------------------------------------------
#-- exe_docs
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS exe_docs;


CREATE TABLE exe_docs
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table exercice_docs',
	exercice_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'exercice',
	nom VARCHAR(255) default 'inc.' NOT NULL COMMENT 'Nom du document',
	affichage CHAR(2)  NOT NULL COMMENT 'Ordre d\'affichage',
	legende VARCHAR(255)  NOT NULL COMMENT 'legende',
	nbre_questions INTEGER(2)  NOT NULL COMMENT 'Nombre de questions',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	PRIMARY KEY (id),
	INDEX exe_docs_FI_1 (exercice_id),
	CONSTRAINT exe_docs_FK_1
		FOREIGN KEY (exercice_id)
		REFERENCES exercices (id)
)Type=MyISAM COMMENT='Liste des documents des exercices';

#-----------------------------------------------------------------------------
#-- exe_doc_questions
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS exe_doc_questions;


CREATE TABLE exe_doc_questions
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table exe_doc_questions',
	exe_doc_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere du document',
	question VARCHAR(255)  NOT NULL COMMENT 'Intitule de la question',
	reponse LONGBLOB  NOT NULL COMMENT 'reponse a la question',
	voir_reponse CHAR(1)  NOT NULL COMMENT 'Voir reponse ?',
	aide VARCHAR(255)  NOT NULL COMMENT 'Contenu de l\'aide',
	affiche_aide CHAR(1)  NOT NULL COMMENT 'Afficher aide ?',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	PRIMARY KEY (id),
	INDEX exe_doc_questions_FI_1 (exe_doc_id),
	CONSTRAINT exe_doc_questions_FK_1
		FOREIGN KEY (exe_doc_id)
		REFERENCES exe_docs (id)
)Type=MyISAM COMMENT='Liste des questions pour chaque document';

#-----------------------------------------------------------------------------
#-- exe_reponses
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS exe_reponses;


CREATE TABLE exe_reponses
(
	id INTEGER(11)  NOT NULL AUTO_INCREMENT COMMENT 'cle primaire de la table exe_doc_questions',
	eleve_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'eleve',
	exercice_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de l\'exercice',
	exe_doc_question_id INTEGER(11)  NOT NULL COMMENT 'cle etrangere de la question',
	reponse LONGBLOB  NOT NULL COMMENT 'reponse a la question',
	rne CHAR(11)  NOT NULL COMMENT 'Rne de l\'etablissement',
	created_on INTEGER(11)  NOT NULL COMMENT 'Date de creation',
	updated_on INTEGER(11)  NOT NULL COMMENT 'Date de modification',
	PRIMARY KEY (id),
	INDEX exe_reponses_FI_1 (eleve_id),
	CONSTRAINT exe_reponses_FK_1
		FOREIGN KEY (eleve_id)
		REFERENCES utilisateurs (id),
	INDEX exe_reponses_FI_2 (exercice_id),
	CONSTRAINT exe_reponses_FK_2
		FOREIGN KEY (exercice_id)
		REFERENCES exercices (id),
	INDEX exe_reponses_FI_3 (exe_doc_question_id),
	CONSTRAINT exe_reponses_FK_3
		FOREIGN KEY (exe_doc_question_id)
		REFERENCES exe_doc_questions (id)
)Type=MyISAM COMMENT='Liste des reponses des eleves';

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
