<?php
/**
 * @version $Id$
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of stats18.
 *
 * stats18 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * stats18 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with stats18.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

class settingshelper {

  /**
   * Attribut qui stocke la liste des settings de l'application
   * @var array
   */
  private $_reglages = '';

  /**
   * Constructeur de l'objet, initialise tous les settings dans un tableau php
   *
   * @return boolean false/true
   */
  public function  __construct() {
    $c = new Criteria();
    $settings = MSettingPeer::doSelect($c);
    foreach ($settings as $setting){
      $reglage[$setting->getNom()] = $setting->getValeur();
      $reglage['id_'.$setting->getNom()] = $setting->getId();
    }

    $this->_reglages = $reglage;

    return true;

  }

  /**
   * Renvoie la valeur du setting (mthode magique)
   *
   * @param string $name
   * @return string LA valeur du setting appele ou un message d'erreur
   */
  public function  __get($name) {
    if (array_key_exists($name, $this->_reglages)){
      return $this->_reglages[$name];
    }else{
      return '<p>Ce r&eacute;glage ('.$name.') n\'existe pas dans cette base</p>';
    }
  }

  /**
   * Permet de modifier ou de crer un nouveau setting
   *
   * @param string $nom nom du setting
   * @param string $valeur valeur du setting
   */
  public function changeSetting($nom, $valeur){
    if ($this->is_new($nom)){
      $this->updateSetting($nom, $valeur);
    }else{
      $this->addSetting($nom, $valeur);
    }
  }

  /**
   * Ajoute un setting  l'application
   *
   * @param string $nom
   * @param string $valeur
   */
  private function addSetting($nom, $valeur){
    $add = new MSetting();
    $add->setNom($nom);
    $add->setValeur($valeur);
    $add->save();

    // Et on l'ajoute  la liste des settings dj charges
    $this->_reglages[$nom] = $valeur;
  }

  private function updateSetting($nom, $valeur){
    $setting = MSettingPeer::retrieveByPK($this->_reglages["id_".$nom]);
    $setting->setValeur($valeur);
    $setting->save();

    $this->_reglages[$nom] = $valeur;
  }

  private function is_new($nom){
    if (array_key_exists($nom, $this->_reglages)){
      // C'est donc un setting qui existe dj
      return true;
    }else{
      return false;
    }
  }
}
?>
